Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +groupName=appintegrations.aws.upbound.io +versionName=v1beta1
Index ¶
- Constants
- Variables
- type EventFilterInitParameters
- type EventFilterObservation
- type EventFilterParameters
- type EventIntegration
- func (tr *EventIntegration) ConvertFrom(srcRaw conversion.Hub) error
- func (tr *EventIntegration) ConvertTo(dstRaw conversion.Hub) error
- func (in *EventIntegration) DeepCopy() *EventIntegration
- func (in *EventIntegration) DeepCopyInto(out *EventIntegration)
- func (in *EventIntegration) DeepCopyObject() runtime.Object
- func (mg *EventIntegration) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *EventIntegration) GetConnectionDetailsMapping() map[string]string
- func (mg *EventIntegration) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *EventIntegration) GetID() string
- func (tr *EventIntegration) GetInitParameters() (map[string]any, error)
- func (mg *EventIntegration) GetManagementPolicies() xpv1.ManagementPolicies
- func (tr *EventIntegration) GetMergedParameters(shouldMergeInitProvider bool) (map[string]any, error)
- func (tr *EventIntegration) GetObservation() (map[string]any, error)
- func (tr *EventIntegration) GetParameters() (map[string]any, error)
- func (mg *EventIntegration) GetProviderConfigReference() *xpv1.Reference
- func (mg *EventIntegration) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *EventIntegration) GetTerraformResourceType() string
- func (tr *EventIntegration) GetTerraformSchemaVersion() int
- func (mg *EventIntegration) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *EventIntegration) LateInitialize(attrs []byte) (bool, error)
- func (mg *EventIntegration) SetConditions(c ...xpv1.Condition)
- func (mg *EventIntegration) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (mg *EventIntegration) SetManagementPolicies(r xpv1.ManagementPolicies)
- func (tr *EventIntegration) SetObservation(obs map[string]any) error
- func (tr *EventIntegration) SetParameters(params map[string]any) error
- func (mg *EventIntegration) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *EventIntegration) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *EventIntegration) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type EventIntegrationInitParameters
- type EventIntegrationList
- type EventIntegrationObservation
- type EventIntegrationParameters
- type EventIntegrationSpec
- type EventIntegrationStatus
Constants ¶
const ( CRDGroup = "appintegrations.aws.upbound.io" CRDVersion = "v1beta1" )
Package type metadata.
Variables ¶
var ( EventIntegration_Kind = "EventIntegration" EventIntegration_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: EventIntegration_Kind}.String() EventIntegration_KindAPIVersion = EventIntegration_Kind + "." + CRDGroupVersion.String() EventIntegration_GroupVersionKind = CRDGroupVersion.WithKind(EventIntegration_Kind) )
Repository type metadata.
var ( // CRDGroupVersion is the API Group Version used to register the objects CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type EventFilterInitParameters ¶ added in v0.38.0
type EventFilterInitParameters struct {
// Source of the events.
Source *string `json:"source,omitempty" tf:"source,omitempty"`
}
func (*EventFilterInitParameters) DeepCopy ¶ added in v0.38.0
func (in *EventFilterInitParameters) DeepCopy() *EventFilterInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventFilterInitParameters.
func (*EventFilterInitParameters) DeepCopyInto ¶ added in v0.38.0
func (in *EventFilterInitParameters) DeepCopyInto(out *EventFilterInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EventFilterObservation ¶
type EventFilterObservation struct {
// Source of the events.
Source *string `json:"source,omitempty" tf:"source,omitempty"`
}
func (*EventFilterObservation) DeepCopy ¶
func (in *EventFilterObservation) DeepCopy() *EventFilterObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventFilterObservation.
func (*EventFilterObservation) DeepCopyInto ¶
func (in *EventFilterObservation) DeepCopyInto(out *EventFilterObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EventFilterParameters ¶
type EventFilterParameters struct {
// Source of the events.
// +kubebuilder:validation:Optional
Source *string `json:"source" tf:"source,omitempty"`
}
func (*EventFilterParameters) DeepCopy ¶
func (in *EventFilterParameters) DeepCopy() *EventFilterParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventFilterParameters.
func (*EventFilterParameters) DeepCopyInto ¶
func (in *EventFilterParameters) DeepCopyInto(out *EventFilterParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EventIntegration ¶
type EventIntegration struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.eventFilter) || (has(self.initProvider) && has(self.initProvider.eventFilter))",message="spec.forProvider.eventFilter is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.eventbridgeBus) || (has(self.initProvider) && has(self.initProvider.eventbridgeBus))",message="spec.forProvider.eventbridgeBus is a required parameter"
Spec EventIntegrationSpec `json:"spec"`
Status EventIntegrationStatus `json:"status,omitempty"`
}
EventIntegration is the Schema for the EventIntegrations API. Provides details about a specific Amazon AppIntegrations Event Integration +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,aws}
func (*EventIntegration) ConvertFrom ¶ added in v1.7.0
func (tr *EventIntegration) ConvertFrom(srcRaw conversion.Hub) error
ConvertFrom converts from the hub type to the EventIntegration type.
func (*EventIntegration) ConvertTo ¶ added in v1.7.0
func (tr *EventIntegration) ConvertTo(dstRaw conversion.Hub) error
ConvertTo converts this EventIntegration to the hub type.
func (*EventIntegration) DeepCopy ¶
func (in *EventIntegration) DeepCopy() *EventIntegration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventIntegration.
func (*EventIntegration) DeepCopyInto ¶
func (in *EventIntegration) DeepCopyInto(out *EventIntegration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*EventIntegration) DeepCopyObject ¶
func (in *EventIntegration) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*EventIntegration) GetCondition ¶
func (mg *EventIntegration) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this EventIntegration.
func (*EventIntegration) GetConnectionDetailsMapping ¶
func (tr *EventIntegration) GetConnectionDetailsMapping() map[string]string
GetConnectionDetailsMapping for this EventIntegration
func (*EventIntegration) GetDeletionPolicy ¶
func (mg *EventIntegration) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this EventIntegration.
func (*EventIntegration) GetID ¶
func (tr *EventIntegration) GetID() string
GetID returns ID of underlying Terraform resource of this EventIntegration
func (*EventIntegration) GetInitParameters ¶ added in v0.38.0
func (tr *EventIntegration) GetInitParameters() (map[string]any, error)
GetInitParameters of this EventIntegration
func (*EventIntegration) GetManagementPolicies ¶ added in v0.38.0
func (mg *EventIntegration) GetManagementPolicies() xpv1.ManagementPolicies
GetManagementPolicies of this EventIntegration.
func (*EventIntegration) GetMergedParameters ¶ added in v0.44.0
func (tr *EventIntegration) GetMergedParameters(shouldMergeInitProvider bool) (map[string]any, error)
GetInitParameters of this EventIntegration
func (*EventIntegration) GetObservation ¶
func (tr *EventIntegration) GetObservation() (map[string]any, error)
GetObservation of this EventIntegration
func (*EventIntegration) GetParameters ¶
func (tr *EventIntegration) GetParameters() (map[string]any, error)
GetParameters of this EventIntegration
func (*EventIntegration) GetProviderConfigReference ¶
func (mg *EventIntegration) GetProviderConfigReference() *xpv1.Reference
GetProviderConfigReference of this EventIntegration.
func (*EventIntegration) GetPublishConnectionDetailsTo ¶
func (mg *EventIntegration) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this EventIntegration.
func (*EventIntegration) GetTerraformResourceType ¶
func (mg *EventIntegration) GetTerraformResourceType() string
GetTerraformResourceType returns Terraform resource type for this EventIntegration
func (*EventIntegration) GetTerraformSchemaVersion ¶
func (tr *EventIntegration) GetTerraformSchemaVersion() int
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*EventIntegration) GetWriteConnectionSecretToReference ¶
func (mg *EventIntegration) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this EventIntegration.
func (*EventIntegration) LateInitialize ¶
func (tr *EventIntegration) LateInitialize(attrs []byte) (bool, error)
LateInitialize this EventIntegration using its observed tfState. returns True if there are any spec changes for the resource.
func (*EventIntegration) SetConditions ¶
func (mg *EventIntegration) SetConditions(c ...xpv1.Condition)
SetConditions of this EventIntegration.
func (*EventIntegration) SetDeletionPolicy ¶
func (mg *EventIntegration) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this EventIntegration.
func (*EventIntegration) SetManagementPolicies ¶ added in v0.38.0
func (mg *EventIntegration) SetManagementPolicies(r xpv1.ManagementPolicies)
SetManagementPolicies of this EventIntegration.
func (*EventIntegration) SetObservation ¶
func (tr *EventIntegration) SetObservation(obs map[string]any) error
SetObservation for this EventIntegration
func (*EventIntegration) SetParameters ¶
func (tr *EventIntegration) SetParameters(params map[string]any) error
SetParameters for this EventIntegration
func (*EventIntegration) SetProviderConfigReference ¶
func (mg *EventIntegration) SetProviderConfigReference(r *xpv1.Reference)
SetProviderConfigReference of this EventIntegration.
func (*EventIntegration) SetPublishConnectionDetailsTo ¶
func (mg *EventIntegration) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this EventIntegration.
func (*EventIntegration) SetWriteConnectionSecretToReference ¶
func (mg *EventIntegration) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this EventIntegration.
type EventIntegrationInitParameters ¶ added in v0.38.0
type EventIntegrationInitParameters struct {
// Description of the Event Integration.
Description *string `json:"description,omitempty" tf:"description,omitempty"`
// Block that defines the configuration information for the event filter. The Event Filter block is documented below.
EventFilter []EventFilterInitParameters `json:"eventFilter,omitempty" tf:"event_filter,omitempty"`
// EventBridge bus.
EventbridgeBus *string `json:"eventbridgeBus,omitempty" tf:"eventbridge_bus,omitempty"`
// Key-value map of resource tags.
// +mapType=granular
Tags map[string]*string `json:"tags,omitempty" tf:"tags,omitempty"`
}
func (*EventIntegrationInitParameters) DeepCopy ¶ added in v0.38.0
func (in *EventIntegrationInitParameters) DeepCopy() *EventIntegrationInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventIntegrationInitParameters.
func (*EventIntegrationInitParameters) DeepCopyInto ¶ added in v0.38.0
func (in *EventIntegrationInitParameters) DeepCopyInto(out *EventIntegrationInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EventIntegrationList ¶
type EventIntegrationList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []EventIntegration `json:"items"`
}
EventIntegrationList contains a list of EventIntegrations
func (*EventIntegrationList) DeepCopy ¶
func (in *EventIntegrationList) DeepCopy() *EventIntegrationList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventIntegrationList.
func (*EventIntegrationList) DeepCopyInto ¶
func (in *EventIntegrationList) DeepCopyInto(out *EventIntegrationList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*EventIntegrationList) DeepCopyObject ¶
func (in *EventIntegrationList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*EventIntegrationList) GetItems ¶
func (l *EventIntegrationList) GetItems() []resource.Managed
GetItems of this EventIntegrationList.
type EventIntegrationObservation ¶
type EventIntegrationObservation struct {
// ARN of the Event Integration.
Arn *string `json:"arn,omitempty" tf:"arn,omitempty"`
// Description of the Event Integration.
Description *string `json:"description,omitempty" tf:"description,omitempty"`
// Block that defines the configuration information for the event filter. The Event Filter block is documented below.
EventFilter []EventFilterObservation `json:"eventFilter,omitempty" tf:"event_filter,omitempty"`
// EventBridge bus.
EventbridgeBus *string `json:"eventbridgeBus,omitempty" tf:"eventbridge_bus,omitempty"`
// Identifier of the Event Integration which is the name of the Event Integration.
ID *string `json:"id,omitempty" tf:"id,omitempty"`
// Key-value map of resource tags.
// +mapType=granular
Tags map[string]*string `json:"tags,omitempty" tf:"tags,omitempty"`
// Map of tags assigned to the resource, including those inherited from the provider default_tags configuration block.
// +mapType=granular
TagsAll map[string]*string `json:"tagsAll,omitempty" tf:"tags_all,omitempty"`
}
func (*EventIntegrationObservation) DeepCopy ¶
func (in *EventIntegrationObservation) DeepCopy() *EventIntegrationObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventIntegrationObservation.
func (*EventIntegrationObservation) DeepCopyInto ¶
func (in *EventIntegrationObservation) DeepCopyInto(out *EventIntegrationObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EventIntegrationParameters ¶
type EventIntegrationParameters struct {
// Description of the Event Integration.
// +kubebuilder:validation:Optional
Description *string `json:"description,omitempty" tf:"description,omitempty"`
// Block that defines the configuration information for the event filter. The Event Filter block is documented below.
// +kubebuilder:validation:Optional
EventFilter []EventFilterParameters `json:"eventFilter,omitempty" tf:"event_filter,omitempty"`
// EventBridge bus.
// +kubebuilder:validation:Optional
EventbridgeBus *string `json:"eventbridgeBus,omitempty" tf:"eventbridge_bus,omitempty"`
// Region is the region you'd like your resource to be created in.
// +upjet:crd:field:TFTag=-
// +kubebuilder:validation:Required
Region *string `json:"region" tf:"-"`
// Key-value map of resource tags.
// +kubebuilder:validation:Optional
// +mapType=granular
Tags map[string]*string `json:"tags,omitempty" tf:"tags,omitempty"`
}
func (*EventIntegrationParameters) DeepCopy ¶
func (in *EventIntegrationParameters) DeepCopy() *EventIntegrationParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventIntegrationParameters.
func (*EventIntegrationParameters) DeepCopyInto ¶
func (in *EventIntegrationParameters) DeepCopyInto(out *EventIntegrationParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EventIntegrationSpec ¶
type EventIntegrationSpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider EventIntegrationParameters `json:"forProvider"`
// THIS IS A BETA FIELD. It will be honored
// unless the Management Policies feature flag is disabled.
// InitProvider holds the same fields as ForProvider, with the exception
// of Identifier and other resource reference fields. The fields that are
// in InitProvider are merged into ForProvider when the resource is created.
// The same fields are also added to the terraform ignore_changes hook, to
// avoid updating them after creation. This is useful for fields that are
// required on creation, but we do not desire to update them after creation,
// for example because of an external controller is managing them, like an
// autoscaler.
InitProvider EventIntegrationInitParameters `json:"initProvider,omitempty"`
}
EventIntegrationSpec defines the desired state of EventIntegration
func (*EventIntegrationSpec) DeepCopy ¶
func (in *EventIntegrationSpec) DeepCopy() *EventIntegrationSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventIntegrationSpec.
func (*EventIntegrationSpec) DeepCopyInto ¶
func (in *EventIntegrationSpec) DeepCopyInto(out *EventIntegrationSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EventIntegrationStatus ¶
type EventIntegrationStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider EventIntegrationObservation `json:"atProvider,omitempty"`
}
EventIntegrationStatus defines the observed state of EventIntegration.
func (*EventIntegrationStatus) DeepCopy ¶
func (in *EventIntegrationStatus) DeepCopy() *EventIntegrationStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventIntegrationStatus.
func (*EventIntegrationStatus) DeepCopyInto ¶
func (in *EventIntegrationStatus) DeepCopyInto(out *EventIntegrationStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.