Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +groupName=ce.aws.upbound.io +versionName=v1beta1
Index ¶
- Constants
- Variables
- type AnomalyMonitor
- func (in *AnomalyMonitor) DeepCopy() *AnomalyMonitor
- func (in *AnomalyMonitor) DeepCopyInto(out *AnomalyMonitor)
- func (in *AnomalyMonitor) DeepCopyObject() runtime.Object
- func (mg *AnomalyMonitor) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *AnomalyMonitor) GetConnectionDetailsMapping() map[string]string
- func (mg *AnomalyMonitor) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *AnomalyMonitor) GetID() string
- func (tr *AnomalyMonitor) GetInitParameters() (map[string]any, error)
- func (mg *AnomalyMonitor) GetManagementPolicies() xpv1.ManagementPolicies
- func (tr *AnomalyMonitor) GetMergedParameters(shouldMergeInitProvider bool) (map[string]any, error)
- func (tr *AnomalyMonitor) GetObservation() (map[string]any, error)
- func (tr *AnomalyMonitor) GetParameters() (map[string]any, error)
- func (mg *AnomalyMonitor) GetProviderConfigReference() *xpv1.Reference
- func (mg *AnomalyMonitor) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *AnomalyMonitor) GetTerraformResourceType() string
- func (tr *AnomalyMonitor) GetTerraformSchemaVersion() int
- func (mg *AnomalyMonitor) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *AnomalyMonitor) Hub()
- func (tr *AnomalyMonitor) LateInitialize(attrs []byte) (bool, error)
- func (mg *AnomalyMonitor) SetConditions(c ...xpv1.Condition)
- func (mg *AnomalyMonitor) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (mg *AnomalyMonitor) SetManagementPolicies(r xpv1.ManagementPolicies)
- func (tr *AnomalyMonitor) SetObservation(obs map[string]any) error
- func (tr *AnomalyMonitor) SetParameters(params map[string]any) error
- func (mg *AnomalyMonitor) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *AnomalyMonitor) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *AnomalyMonitor) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type AnomalyMonitorInitParameters
- type AnomalyMonitorList
- type AnomalyMonitorObservation
- type AnomalyMonitorParameters
- type AnomalyMonitorSpec
- type AnomalyMonitorStatus
Constants ¶
const ( CRDGroup = "ce.aws.upbound.io" CRDVersion = "v1beta1" )
Package type metadata.
Variables ¶
var ( AnomalyMonitor_Kind = "AnomalyMonitor" AnomalyMonitor_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: AnomalyMonitor_Kind}.String() AnomalyMonitor_KindAPIVersion = AnomalyMonitor_Kind + "." + CRDGroupVersion.String() AnomalyMonitor_GroupVersionKind = CRDGroupVersion.WithKind(AnomalyMonitor_Kind) )
Repository type metadata.
var ( // CRDGroupVersion is the API Group Version used to register the objects CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type AnomalyMonitor ¶
type AnomalyMonitor struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.monitorType) || (has(self.initProvider) && has(self.initProvider.monitorType))",message="spec.forProvider.monitorType is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.name) || (has(self.initProvider) && has(self.initProvider.name))",message="spec.forProvider.name is a required parameter"
Spec AnomalyMonitorSpec `json:"spec"`
Status AnomalyMonitorStatus `json:"status,omitempty"`
}
AnomalyMonitor is the Schema for the AnomalyMonitors API. Provides a CE Cost Anomaly Monitor +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,aws}
func (*AnomalyMonitor) DeepCopy ¶
func (in *AnomalyMonitor) DeepCopy() *AnomalyMonitor
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AnomalyMonitor.
func (*AnomalyMonitor) DeepCopyInto ¶
func (in *AnomalyMonitor) DeepCopyInto(out *AnomalyMonitor)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*AnomalyMonitor) DeepCopyObject ¶
func (in *AnomalyMonitor) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*AnomalyMonitor) GetCondition ¶
func (mg *AnomalyMonitor) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this AnomalyMonitor.
func (*AnomalyMonitor) GetConnectionDetailsMapping ¶
func (tr *AnomalyMonitor) GetConnectionDetailsMapping() map[string]string
GetConnectionDetailsMapping for this AnomalyMonitor
func (*AnomalyMonitor) GetDeletionPolicy ¶
func (mg *AnomalyMonitor) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this AnomalyMonitor.
func (*AnomalyMonitor) GetID ¶
func (tr *AnomalyMonitor) GetID() string
GetID returns ID of underlying Terraform resource of this AnomalyMonitor
func (*AnomalyMonitor) GetInitParameters ¶ added in v0.38.0
func (tr *AnomalyMonitor) GetInitParameters() (map[string]any, error)
GetInitParameters of this AnomalyMonitor
func (*AnomalyMonitor) GetManagementPolicies ¶ added in v0.38.0
func (mg *AnomalyMonitor) GetManagementPolicies() xpv1.ManagementPolicies
GetManagementPolicies of this AnomalyMonitor.
func (*AnomalyMonitor) GetMergedParameters ¶ added in v0.44.0
func (tr *AnomalyMonitor) GetMergedParameters(shouldMergeInitProvider bool) (map[string]any, error)
GetInitParameters of this AnomalyMonitor
func (*AnomalyMonitor) GetObservation ¶
func (tr *AnomalyMonitor) GetObservation() (map[string]any, error)
GetObservation of this AnomalyMonitor
func (*AnomalyMonitor) GetParameters ¶
func (tr *AnomalyMonitor) GetParameters() (map[string]any, error)
GetParameters of this AnomalyMonitor
func (*AnomalyMonitor) GetProviderConfigReference ¶
func (mg *AnomalyMonitor) GetProviderConfigReference() *xpv1.Reference
GetProviderConfigReference of this AnomalyMonitor.
func (*AnomalyMonitor) GetPublishConnectionDetailsTo ¶
func (mg *AnomalyMonitor) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this AnomalyMonitor.
func (*AnomalyMonitor) GetTerraformResourceType ¶
func (mg *AnomalyMonitor) GetTerraformResourceType() string
GetTerraformResourceType returns Terraform resource type for this AnomalyMonitor
func (*AnomalyMonitor) GetTerraformSchemaVersion ¶
func (tr *AnomalyMonitor) GetTerraformSchemaVersion() int
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*AnomalyMonitor) GetWriteConnectionSecretToReference ¶
func (mg *AnomalyMonitor) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this AnomalyMonitor.
func (*AnomalyMonitor) Hub ¶ added in v0.47.2
func (tr *AnomalyMonitor) Hub()
Hub marks this type as a conversion hub.
func (*AnomalyMonitor) LateInitialize ¶
func (tr *AnomalyMonitor) LateInitialize(attrs []byte) (bool, error)
LateInitialize this AnomalyMonitor using its observed tfState. returns True if there are any spec changes for the resource.
func (*AnomalyMonitor) SetConditions ¶
func (mg *AnomalyMonitor) SetConditions(c ...xpv1.Condition)
SetConditions of this AnomalyMonitor.
func (*AnomalyMonitor) SetDeletionPolicy ¶
func (mg *AnomalyMonitor) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this AnomalyMonitor.
func (*AnomalyMonitor) SetManagementPolicies ¶ added in v0.38.0
func (mg *AnomalyMonitor) SetManagementPolicies(r xpv1.ManagementPolicies)
SetManagementPolicies of this AnomalyMonitor.
func (*AnomalyMonitor) SetObservation ¶
func (tr *AnomalyMonitor) SetObservation(obs map[string]any) error
SetObservation for this AnomalyMonitor
func (*AnomalyMonitor) SetParameters ¶
func (tr *AnomalyMonitor) SetParameters(params map[string]any) error
SetParameters for this AnomalyMonitor
func (*AnomalyMonitor) SetProviderConfigReference ¶
func (mg *AnomalyMonitor) SetProviderConfigReference(r *xpv1.Reference)
SetProviderConfigReference of this AnomalyMonitor.
func (*AnomalyMonitor) SetPublishConnectionDetailsTo ¶
func (mg *AnomalyMonitor) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this AnomalyMonitor.
func (*AnomalyMonitor) SetWriteConnectionSecretToReference ¶
func (mg *AnomalyMonitor) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this AnomalyMonitor.
type AnomalyMonitorInitParameters ¶ added in v0.38.0
type AnomalyMonitorInitParameters struct {
// The dimensions to evaluate. Valid values: SERVICE.
MonitorDimension *string `json:"monitorDimension,omitempty" tf:"monitor_dimension,omitempty"`
// A valid JSON representation for the Expression object.
MonitorSpecification *string `json:"monitorSpecification,omitempty" tf:"monitor_specification,omitempty"`
// The possible type values. Valid values: DIMENSIONAL | CUSTOM.
MonitorType *string `json:"monitorType,omitempty" tf:"monitor_type,omitempty"`
// The name of the monitor.
Name *string `json:"name,omitempty" tf:"name,omitempty"`
// Key-value map of resource tags.
// +mapType=granular
Tags map[string]*string `json:"tags,omitempty" tf:"tags,omitempty"`
}
func (*AnomalyMonitorInitParameters) DeepCopy ¶ added in v0.38.0
func (in *AnomalyMonitorInitParameters) DeepCopy() *AnomalyMonitorInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AnomalyMonitorInitParameters.
func (*AnomalyMonitorInitParameters) DeepCopyInto ¶ added in v0.38.0
func (in *AnomalyMonitorInitParameters) DeepCopyInto(out *AnomalyMonitorInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type AnomalyMonitorList ¶
type AnomalyMonitorList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []AnomalyMonitor `json:"items"`
}
AnomalyMonitorList contains a list of AnomalyMonitors
func (*AnomalyMonitorList) DeepCopy ¶
func (in *AnomalyMonitorList) DeepCopy() *AnomalyMonitorList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AnomalyMonitorList.
func (*AnomalyMonitorList) DeepCopyInto ¶
func (in *AnomalyMonitorList) DeepCopyInto(out *AnomalyMonitorList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*AnomalyMonitorList) DeepCopyObject ¶
func (in *AnomalyMonitorList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*AnomalyMonitorList) GetItems ¶
func (l *AnomalyMonitorList) GetItems() []resource.Managed
GetItems of this AnomalyMonitorList.
type AnomalyMonitorObservation ¶
type AnomalyMonitorObservation struct {
// ARN of the anomaly monitor.
Arn *string `json:"arn,omitempty" tf:"arn,omitempty"`
// Unique ID of the anomaly monitor. Same as arn.
ID *string `json:"id,omitempty" tf:"id,omitempty"`
// The dimensions to evaluate. Valid values: SERVICE.
MonitorDimension *string `json:"monitorDimension,omitempty" tf:"monitor_dimension,omitempty"`
// A valid JSON representation for the Expression object.
MonitorSpecification *string `json:"monitorSpecification,omitempty" tf:"monitor_specification,omitempty"`
// The possible type values. Valid values: DIMENSIONAL | CUSTOM.
MonitorType *string `json:"monitorType,omitempty" tf:"monitor_type,omitempty"`
// The name of the monitor.
Name *string `json:"name,omitempty" tf:"name,omitempty"`
// Key-value map of resource tags.
// +mapType=granular
Tags map[string]*string `json:"tags,omitempty" tf:"tags,omitempty"`
// A map of tags assigned to the resource, including those inherited from the provider default_tags configuration block.
// +mapType=granular
TagsAll map[string]*string `json:"tagsAll,omitempty" tf:"tags_all,omitempty"`
}
func (*AnomalyMonitorObservation) DeepCopy ¶
func (in *AnomalyMonitorObservation) DeepCopy() *AnomalyMonitorObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AnomalyMonitorObservation.
func (*AnomalyMonitorObservation) DeepCopyInto ¶
func (in *AnomalyMonitorObservation) DeepCopyInto(out *AnomalyMonitorObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type AnomalyMonitorParameters ¶
type AnomalyMonitorParameters struct {
// The dimensions to evaluate. Valid values: SERVICE.
// +kubebuilder:validation:Optional
MonitorDimension *string `json:"monitorDimension,omitempty" tf:"monitor_dimension,omitempty"`
// A valid JSON representation for the Expression object.
// +kubebuilder:validation:Optional
MonitorSpecification *string `json:"monitorSpecification,omitempty" tf:"monitor_specification,omitempty"`
// The possible type values. Valid values: DIMENSIONAL | CUSTOM.
// +kubebuilder:validation:Optional
MonitorType *string `json:"monitorType,omitempty" tf:"monitor_type,omitempty"`
// The name of the monitor.
// +kubebuilder:validation:Optional
Name *string `json:"name,omitempty" tf:"name,omitempty"`
// Region is the region you'd like your resource to be created in.
// +upjet:crd:field:TFTag=-
// +kubebuilder:validation:Required
Region *string `json:"region" tf:"-"`
// Key-value map of resource tags.
// +kubebuilder:validation:Optional
// +mapType=granular
Tags map[string]*string `json:"tags,omitempty" tf:"tags,omitempty"`
}
func (*AnomalyMonitorParameters) DeepCopy ¶
func (in *AnomalyMonitorParameters) DeepCopy() *AnomalyMonitorParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AnomalyMonitorParameters.
func (*AnomalyMonitorParameters) DeepCopyInto ¶
func (in *AnomalyMonitorParameters) DeepCopyInto(out *AnomalyMonitorParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type AnomalyMonitorSpec ¶
type AnomalyMonitorSpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider AnomalyMonitorParameters `json:"forProvider"`
// THIS IS A BETA FIELD. It will be honored
// unless the Management Policies feature flag is disabled.
// InitProvider holds the same fields as ForProvider, with the exception
// of Identifier and other resource reference fields. The fields that are
// in InitProvider are merged into ForProvider when the resource is created.
// The same fields are also added to the terraform ignore_changes hook, to
// avoid updating them after creation. This is useful for fields that are
// required on creation, but we do not desire to update them after creation,
// for example because of an external controller is managing them, like an
// autoscaler.
InitProvider AnomalyMonitorInitParameters `json:"initProvider,omitempty"`
}
AnomalyMonitorSpec defines the desired state of AnomalyMonitor
func (*AnomalyMonitorSpec) DeepCopy ¶
func (in *AnomalyMonitorSpec) DeepCopy() *AnomalyMonitorSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AnomalyMonitorSpec.
func (*AnomalyMonitorSpec) DeepCopyInto ¶
func (in *AnomalyMonitorSpec) DeepCopyInto(out *AnomalyMonitorSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type AnomalyMonitorStatus ¶
type AnomalyMonitorStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider AnomalyMonitorObservation `json:"atProvider,omitempty"`
}
AnomalyMonitorStatus defines the observed state of AnomalyMonitor.
func (*AnomalyMonitorStatus) DeepCopy ¶
func (in *AnomalyMonitorStatus) DeepCopy() *AnomalyMonitorStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AnomalyMonitorStatus.
func (*AnomalyMonitorStatus) DeepCopyInto ¶
func (in *AnomalyMonitorStatus) DeepCopyInto(out *AnomalyMonitorStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.