Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +groupName=cloud9.aws.upbound.io +versionName=v1beta1
Index ¶
- Constants
- Variables
- type EnvironmentEC2
- func (in *EnvironmentEC2) DeepCopy() *EnvironmentEC2
- func (in *EnvironmentEC2) DeepCopyInto(out *EnvironmentEC2)
- func (in *EnvironmentEC2) DeepCopyObject() runtime.Object
- func (mg *EnvironmentEC2) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *EnvironmentEC2) GetConnectionDetailsMapping() map[string]string
- func (mg *EnvironmentEC2) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *EnvironmentEC2) GetID() string
- func (tr *EnvironmentEC2) GetObservation() (map[string]any, error)
- func (tr *EnvironmentEC2) GetParameters() (map[string]any, error)
- func (mg *EnvironmentEC2) GetProviderConfigReference() *xpv1.Reference
- func (mg *EnvironmentEC2) GetProviderReference() *xpv1.Reference
- func (mg *EnvironmentEC2) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *EnvironmentEC2) GetTerraformResourceType() string
- func (tr *EnvironmentEC2) GetTerraformSchemaVersion() int
- func (mg *EnvironmentEC2) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *EnvironmentEC2) LateInitialize(attrs []byte) (bool, error)
- func (mg *EnvironmentEC2) ResolveReferences(ctx context.Context, c client.Reader) error
- func (mg *EnvironmentEC2) SetConditions(c ...xpv1.Condition)
- func (mg *EnvironmentEC2) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (tr *EnvironmentEC2) SetObservation(obs map[string]any) error
- func (tr *EnvironmentEC2) SetParameters(params map[string]any) error
- func (mg *EnvironmentEC2) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *EnvironmentEC2) SetProviderReference(r *xpv1.Reference)
- func (mg *EnvironmentEC2) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *EnvironmentEC2) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type EnvironmentEC2List
- type EnvironmentEC2Observation
- type EnvironmentEC2Parameters
- type EnvironmentEC2Spec
- type EnvironmentEC2Status
- type EnvironmentMembership
- func (in *EnvironmentMembership) DeepCopy() *EnvironmentMembership
- func (in *EnvironmentMembership) DeepCopyInto(out *EnvironmentMembership)
- func (in *EnvironmentMembership) DeepCopyObject() runtime.Object
- func (mg *EnvironmentMembership) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *EnvironmentMembership) GetConnectionDetailsMapping() map[string]string
- func (mg *EnvironmentMembership) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *EnvironmentMembership) GetID() string
- func (tr *EnvironmentMembership) GetObservation() (map[string]any, error)
- func (tr *EnvironmentMembership) GetParameters() (map[string]any, error)
- func (mg *EnvironmentMembership) GetProviderConfigReference() *xpv1.Reference
- func (mg *EnvironmentMembership) GetProviderReference() *xpv1.Reference
- func (mg *EnvironmentMembership) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *EnvironmentMembership) GetTerraformResourceType() string
- func (tr *EnvironmentMembership) GetTerraformSchemaVersion() int
- func (mg *EnvironmentMembership) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *EnvironmentMembership) LateInitialize(attrs []byte) (bool, error)
- func (mg *EnvironmentMembership) ResolveReferences(ctx context.Context, c client.Reader) error
- func (mg *EnvironmentMembership) SetConditions(c ...xpv1.Condition)
- func (mg *EnvironmentMembership) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (tr *EnvironmentMembership) SetObservation(obs map[string]any) error
- func (tr *EnvironmentMembership) SetParameters(params map[string]any) error
- func (mg *EnvironmentMembership) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *EnvironmentMembership) SetProviderReference(r *xpv1.Reference)
- func (mg *EnvironmentMembership) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *EnvironmentMembership) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type EnvironmentMembershipList
- type EnvironmentMembershipObservation
- type EnvironmentMembershipParameters
- type EnvironmentMembershipSpec
- type EnvironmentMembershipStatus
Constants ¶
const ( CRDGroup = "cloud9.aws.upbound.io" CRDVersion = "v1beta1" )
Package type metadata.
Variables ¶
var ( EnvironmentEC2_Kind = "EnvironmentEC2" EnvironmentEC2_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: EnvironmentEC2_Kind}.String() EnvironmentEC2_KindAPIVersion = EnvironmentEC2_Kind + "." + CRDGroupVersion.String() EnvironmentEC2_GroupVersionKind = CRDGroupVersion.WithKind(EnvironmentEC2_Kind) )
Repository type metadata.
var ( EnvironmentMembership_Kind = "EnvironmentMembership" EnvironmentMembership_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: EnvironmentMembership_Kind}.String() EnvironmentMembership_KindAPIVersion = EnvironmentMembership_Kind + "." + CRDGroupVersion.String() EnvironmentMembership_GroupVersionKind = CRDGroupVersion.WithKind(EnvironmentMembership_Kind) )
Repository type metadata.
var ( // CRDGroupVersion is the API Group Version used to register the objects CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type EnvironmentEC2 ¶
type EnvironmentEC2 struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec EnvironmentEC2Spec `json:"spec"`
Status EnvironmentEC2Status `json:"status,omitempty"`
}
EnvironmentEC2 is the Schema for the EnvironmentEC2s API. Provides a Cloud9 EC2 Development Environment. +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,aws}
func (*EnvironmentEC2) DeepCopy ¶
func (in *EnvironmentEC2) DeepCopy() *EnvironmentEC2
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EnvironmentEC2.
func (*EnvironmentEC2) DeepCopyInto ¶
func (in *EnvironmentEC2) DeepCopyInto(out *EnvironmentEC2)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*EnvironmentEC2) DeepCopyObject ¶
func (in *EnvironmentEC2) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*EnvironmentEC2) GetCondition ¶
func (mg *EnvironmentEC2) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this EnvironmentEC2.
func (*EnvironmentEC2) GetConnectionDetailsMapping ¶
func (tr *EnvironmentEC2) GetConnectionDetailsMapping() map[string]string
GetConnectionDetailsMapping for this EnvironmentEC2
func (*EnvironmentEC2) GetDeletionPolicy ¶
func (mg *EnvironmentEC2) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this EnvironmentEC2.
func (*EnvironmentEC2) GetID ¶
func (tr *EnvironmentEC2) GetID() string
GetID returns ID of underlying Terraform resource of this EnvironmentEC2
func (*EnvironmentEC2) GetObservation ¶
func (tr *EnvironmentEC2) GetObservation() (map[string]any, error)
GetObservation of this EnvironmentEC2
func (*EnvironmentEC2) GetParameters ¶
func (tr *EnvironmentEC2) GetParameters() (map[string]any, error)
GetParameters of this EnvironmentEC2
func (*EnvironmentEC2) GetProviderConfigReference ¶
func (mg *EnvironmentEC2) GetProviderConfigReference() *xpv1.Reference
GetProviderConfigReference of this EnvironmentEC2.
func (*EnvironmentEC2) GetProviderReference ¶
func (mg *EnvironmentEC2) GetProviderReference() *xpv1.Reference
GetProviderReference of this EnvironmentEC2. Deprecated: Use GetProviderConfigReference.
func (*EnvironmentEC2) GetPublishConnectionDetailsTo ¶
func (mg *EnvironmentEC2) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this EnvironmentEC2.
func (*EnvironmentEC2) GetTerraformResourceType ¶
func (mg *EnvironmentEC2) GetTerraformResourceType() string
GetTerraformResourceType returns Terraform resource type for this EnvironmentEC2
func (*EnvironmentEC2) GetTerraformSchemaVersion ¶
func (tr *EnvironmentEC2) GetTerraformSchemaVersion() int
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*EnvironmentEC2) GetWriteConnectionSecretToReference ¶
func (mg *EnvironmentEC2) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this EnvironmentEC2.
func (*EnvironmentEC2) LateInitialize ¶
func (tr *EnvironmentEC2) LateInitialize(attrs []byte) (bool, error)
LateInitialize this EnvironmentEC2 using its observed tfState. returns True if there are any spec changes for the resource.
func (*EnvironmentEC2) ResolveReferences ¶
ResolveReferences of this EnvironmentEC2.
func (*EnvironmentEC2) SetConditions ¶
func (mg *EnvironmentEC2) SetConditions(c ...xpv1.Condition)
SetConditions of this EnvironmentEC2.
func (*EnvironmentEC2) SetDeletionPolicy ¶
func (mg *EnvironmentEC2) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this EnvironmentEC2.
func (*EnvironmentEC2) SetObservation ¶
func (tr *EnvironmentEC2) SetObservation(obs map[string]any) error
SetObservation for this EnvironmentEC2
func (*EnvironmentEC2) SetParameters ¶
func (tr *EnvironmentEC2) SetParameters(params map[string]any) error
SetParameters for this EnvironmentEC2
func (*EnvironmentEC2) SetProviderConfigReference ¶
func (mg *EnvironmentEC2) SetProviderConfigReference(r *xpv1.Reference)
SetProviderConfigReference of this EnvironmentEC2.
func (*EnvironmentEC2) SetProviderReference ¶
func (mg *EnvironmentEC2) SetProviderReference(r *xpv1.Reference)
SetProviderReference of this EnvironmentEC2. Deprecated: Use SetProviderConfigReference.
func (*EnvironmentEC2) SetPublishConnectionDetailsTo ¶
func (mg *EnvironmentEC2) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this EnvironmentEC2.
func (*EnvironmentEC2) SetWriteConnectionSecretToReference ¶
func (mg *EnvironmentEC2) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this EnvironmentEC2.
type EnvironmentEC2List ¶
type EnvironmentEC2List struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []EnvironmentEC2 `json:"items"`
}
EnvironmentEC2List contains a list of EnvironmentEC2s
func (*EnvironmentEC2List) DeepCopy ¶
func (in *EnvironmentEC2List) DeepCopy() *EnvironmentEC2List
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EnvironmentEC2List.
func (*EnvironmentEC2List) DeepCopyInto ¶
func (in *EnvironmentEC2List) DeepCopyInto(out *EnvironmentEC2List)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*EnvironmentEC2List) DeepCopyObject ¶
func (in *EnvironmentEC2List) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*EnvironmentEC2List) GetItems ¶
func (l *EnvironmentEC2List) GetItems() []resource.Managed
GetItems of this EnvironmentEC2List.
type EnvironmentEC2Observation ¶
type EnvironmentEC2Observation struct {
// The ARN of the environment.
Arn *string `json:"arn,omitempty" tf:"arn,omitempty"`
// The ID of the environment.
ID *string `json:"id,omitempty" tf:"id,omitempty"`
// A map of tags assigned to the resource, including those inherited from the provider default_tags configuration block.
TagsAll map[string]*string `json:"tagsAll,omitempty" tf:"tags_all,omitempty"`
// The type of the environment (e.g., ssh or ec2)
Type *string `json:"type,omitempty" tf:"type,omitempty"`
}
func (*EnvironmentEC2Observation) DeepCopy ¶
func (in *EnvironmentEC2Observation) DeepCopy() *EnvironmentEC2Observation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EnvironmentEC2Observation.
func (*EnvironmentEC2Observation) DeepCopyInto ¶
func (in *EnvironmentEC2Observation) DeepCopyInto(out *EnvironmentEC2Observation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EnvironmentEC2Parameters ¶
type EnvironmentEC2Parameters struct {
// The number of minutes until the running instance is shut down after the environment has last been used.
// +kubebuilder:validation:Optional
AutomaticStopTimeMinutes *float64 `json:"automaticStopTimeMinutes,omitempty" tf:"automatic_stop_time_minutes,omitempty"`
// The connection type used for connecting to an Amazon EC2 environment. Valid values are CONNECT_SSH and CONNECT_SSM. For more information please refer AWS documentation for Cloud9.
// +kubebuilder:validation:Optional
ConnectionType *string `json:"connectionType,omitempty" tf:"connection_type,omitempty"`
// The description of the environment.
// +kubebuilder:validation:Optional
Description *string `json:"description,omitempty" tf:"description,omitempty"`
// The identifier for the Amazon Machine Image (AMI) that's used to create the EC2 instance. Valid values are
// +kubebuilder:validation:Optional
ImageID *string `json:"imageId,omitempty" tf:"image_id,omitempty"`
// The type of instance to connect to the environment, e.g., t2.micro.
// +kubebuilder:validation:Required
InstanceType *string `json:"instanceType" tf:"instance_type,omitempty"`
// The name of the environment.
// +kubebuilder:validation:Required
Name *string `json:"name" tf:"name,omitempty"`
// The ARN of the environment owner. This can be ARN of any AWS IAM principal. Defaults to the environment's creator.
// +kubebuilder:validation:Optional
OwnerArn *string `json:"ownerArn,omitempty" tf:"owner_arn,omitempty"`
// Region is the region you'd like your resource to be created in.
// +upjet:crd:field:TFTag=-
// +kubebuilder:validation:Required
Region *string `json:"region" tf:"-"`
// The ID of the subnet in Amazon VPC that AWS Cloud9 will use to communicate with the Amazon EC2 instance.
// +crossplane:generate:reference:type=github.com/upbound/provider-aws/apis/ec2/v1beta1.Subnet
// +kubebuilder:validation:Optional
SubnetID *string `json:"subnetId,omitempty" tf:"subnet_id,omitempty"`
// Reference to a Subnet in ec2 to populate subnetId.
// +kubebuilder:validation:Optional
SubnetIDRef *v1.Reference `json:"subnetIdRef,omitempty" tf:"-"`
// Selector for a Subnet in ec2 to populate subnetId.
// +kubebuilder:validation:Optional
SubnetIDSelector *v1.Selector `json:"subnetIdSelector,omitempty" tf:"-"`
// Key-value map of resource tags.
// +kubebuilder:validation:Optional
Tags map[string]*string `json:"tags,omitempty" tf:"tags,omitempty"`
}
func (*EnvironmentEC2Parameters) DeepCopy ¶
func (in *EnvironmentEC2Parameters) DeepCopy() *EnvironmentEC2Parameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EnvironmentEC2Parameters.
func (*EnvironmentEC2Parameters) DeepCopyInto ¶
func (in *EnvironmentEC2Parameters) DeepCopyInto(out *EnvironmentEC2Parameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EnvironmentEC2Spec ¶
type EnvironmentEC2Spec struct {
v1.ResourceSpec `json:",inline"`
ForProvider EnvironmentEC2Parameters `json:"forProvider"`
}
EnvironmentEC2Spec defines the desired state of EnvironmentEC2
func (*EnvironmentEC2Spec) DeepCopy ¶
func (in *EnvironmentEC2Spec) DeepCopy() *EnvironmentEC2Spec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EnvironmentEC2Spec.
func (*EnvironmentEC2Spec) DeepCopyInto ¶
func (in *EnvironmentEC2Spec) DeepCopyInto(out *EnvironmentEC2Spec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EnvironmentEC2Status ¶
type EnvironmentEC2Status struct {
v1.ResourceStatus `json:",inline"`
AtProvider EnvironmentEC2Observation `json:"atProvider,omitempty"`
}
EnvironmentEC2Status defines the observed state of EnvironmentEC2.
func (*EnvironmentEC2Status) DeepCopy ¶
func (in *EnvironmentEC2Status) DeepCopy() *EnvironmentEC2Status
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EnvironmentEC2Status.
func (*EnvironmentEC2Status) DeepCopyInto ¶
func (in *EnvironmentEC2Status) DeepCopyInto(out *EnvironmentEC2Status)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EnvironmentMembership ¶
type EnvironmentMembership struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec EnvironmentMembershipSpec `json:"spec"`
Status EnvironmentMembershipStatus `json:"status,omitempty"`
}
EnvironmentMembership is the Schema for the EnvironmentMemberships API. Provides an environment member to an AWS Cloud9 development environment. +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,aws}
func (*EnvironmentMembership) DeepCopy ¶
func (in *EnvironmentMembership) DeepCopy() *EnvironmentMembership
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EnvironmentMembership.
func (*EnvironmentMembership) DeepCopyInto ¶
func (in *EnvironmentMembership) DeepCopyInto(out *EnvironmentMembership)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*EnvironmentMembership) DeepCopyObject ¶
func (in *EnvironmentMembership) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*EnvironmentMembership) GetCondition ¶
func (mg *EnvironmentMembership) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this EnvironmentMembership.
func (*EnvironmentMembership) GetConnectionDetailsMapping ¶
func (tr *EnvironmentMembership) GetConnectionDetailsMapping() map[string]string
GetConnectionDetailsMapping for this EnvironmentMembership
func (*EnvironmentMembership) GetDeletionPolicy ¶
func (mg *EnvironmentMembership) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this EnvironmentMembership.
func (*EnvironmentMembership) GetID ¶
func (tr *EnvironmentMembership) GetID() string
GetID returns ID of underlying Terraform resource of this EnvironmentMembership
func (*EnvironmentMembership) GetObservation ¶
func (tr *EnvironmentMembership) GetObservation() (map[string]any, error)
GetObservation of this EnvironmentMembership
func (*EnvironmentMembership) GetParameters ¶
func (tr *EnvironmentMembership) GetParameters() (map[string]any, error)
GetParameters of this EnvironmentMembership
func (*EnvironmentMembership) GetProviderConfigReference ¶
func (mg *EnvironmentMembership) GetProviderConfigReference() *xpv1.Reference
GetProviderConfigReference of this EnvironmentMembership.
func (*EnvironmentMembership) GetProviderReference ¶
func (mg *EnvironmentMembership) GetProviderReference() *xpv1.Reference
GetProviderReference of this EnvironmentMembership. Deprecated: Use GetProviderConfigReference.
func (*EnvironmentMembership) GetPublishConnectionDetailsTo ¶
func (mg *EnvironmentMembership) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this EnvironmentMembership.
func (*EnvironmentMembership) GetTerraformResourceType ¶
func (mg *EnvironmentMembership) GetTerraformResourceType() string
GetTerraformResourceType returns Terraform resource type for this EnvironmentMembership
func (*EnvironmentMembership) GetTerraformSchemaVersion ¶
func (tr *EnvironmentMembership) GetTerraformSchemaVersion() int
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*EnvironmentMembership) GetWriteConnectionSecretToReference ¶
func (mg *EnvironmentMembership) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this EnvironmentMembership.
func (*EnvironmentMembership) LateInitialize ¶
func (tr *EnvironmentMembership) LateInitialize(attrs []byte) (bool, error)
LateInitialize this EnvironmentMembership using its observed tfState. returns True if there are any spec changes for the resource.
func (*EnvironmentMembership) ResolveReferences ¶
ResolveReferences of this EnvironmentMembership.
func (*EnvironmentMembership) SetConditions ¶
func (mg *EnvironmentMembership) SetConditions(c ...xpv1.Condition)
SetConditions of this EnvironmentMembership.
func (*EnvironmentMembership) SetDeletionPolicy ¶
func (mg *EnvironmentMembership) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this EnvironmentMembership.
func (*EnvironmentMembership) SetObservation ¶
func (tr *EnvironmentMembership) SetObservation(obs map[string]any) error
SetObservation for this EnvironmentMembership
func (*EnvironmentMembership) SetParameters ¶
func (tr *EnvironmentMembership) SetParameters(params map[string]any) error
SetParameters for this EnvironmentMembership
func (*EnvironmentMembership) SetProviderConfigReference ¶
func (mg *EnvironmentMembership) SetProviderConfigReference(r *xpv1.Reference)
SetProviderConfigReference of this EnvironmentMembership.
func (*EnvironmentMembership) SetProviderReference ¶
func (mg *EnvironmentMembership) SetProviderReference(r *xpv1.Reference)
SetProviderReference of this EnvironmentMembership. Deprecated: Use SetProviderConfigReference.
func (*EnvironmentMembership) SetPublishConnectionDetailsTo ¶
func (mg *EnvironmentMembership) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this EnvironmentMembership.
func (*EnvironmentMembership) SetWriteConnectionSecretToReference ¶
func (mg *EnvironmentMembership) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this EnvironmentMembership.
type EnvironmentMembershipList ¶
type EnvironmentMembershipList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []EnvironmentMembership `json:"items"`
}
EnvironmentMembershipList contains a list of EnvironmentMemberships
func (*EnvironmentMembershipList) DeepCopy ¶
func (in *EnvironmentMembershipList) DeepCopy() *EnvironmentMembershipList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EnvironmentMembershipList.
func (*EnvironmentMembershipList) DeepCopyInto ¶
func (in *EnvironmentMembershipList) DeepCopyInto(out *EnvironmentMembershipList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*EnvironmentMembershipList) DeepCopyObject ¶
func (in *EnvironmentMembershipList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*EnvironmentMembershipList) GetItems ¶
func (l *EnvironmentMembershipList) GetItems() []resource.Managed
GetItems of this EnvironmentMembershipList.
type EnvironmentMembershipObservation ¶
type EnvironmentMembershipObservation struct {
// The ID of the environment membership.
ID *string `json:"id,omitempty" tf:"id,omitempty"`
// he user ID in AWS Identity and Access Management (AWS IAM) of the environment member.
UserID *string `json:"userId,omitempty" tf:"user_id,omitempty"`
}
func (*EnvironmentMembershipObservation) DeepCopy ¶
func (in *EnvironmentMembershipObservation) DeepCopy() *EnvironmentMembershipObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EnvironmentMembershipObservation.
func (*EnvironmentMembershipObservation) DeepCopyInto ¶
func (in *EnvironmentMembershipObservation) DeepCopyInto(out *EnvironmentMembershipObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EnvironmentMembershipParameters ¶
type EnvironmentMembershipParameters struct {
// The ID of the environment that contains the environment member you want to add.
// +crossplane:generate:reference:type=github.com/upbound/provider-aws/apis/cloud9/v1beta1.EnvironmentEC2
// +crossplane:generate:reference:extractor=github.com/upbound/upjet/pkg/resource.ExtractResourceID()
// +kubebuilder:validation:Optional
EnvironmentID *string `json:"environmentId,omitempty" tf:"environment_id,omitempty"`
// Reference to a EnvironmentEC2 in cloud9 to populate environmentId.
// +kubebuilder:validation:Optional
EnvironmentIDRef *v1.Reference `json:"environmentIdRef,omitempty" tf:"-"`
// Selector for a EnvironmentEC2 in cloud9 to populate environmentId.
// +kubebuilder:validation:Optional
EnvironmentIDSelector *v1.Selector `json:"environmentIdSelector,omitempty" tf:"-"`
// The type of environment member permissions you want to associate with this environment member. Allowed values are read-only and read-write .
// +kubebuilder:validation:Required
Permissions *string `json:"permissions" tf:"permissions,omitempty"`
// Region is the region you'd like your resource to be created in.
// +upjet:crd:field:TFTag=-
// +kubebuilder:validation:Required
Region *string `json:"region" tf:"-"`
// The Amazon Resource Name (ARN) of the environment member you want to add.
// +crossplane:generate:reference:type=github.com/upbound/provider-aws/apis/iam/v1beta1.User
// +crossplane:generate:reference:extractor=github.com/upbound/upjet/pkg/resource.ExtractParamPath("arn",true)
// +kubebuilder:validation:Optional
UserArn *string `json:"userArn,omitempty" tf:"user_arn,omitempty"`
// Reference to a User in iam to populate userArn.
// +kubebuilder:validation:Optional
UserArnRef *v1.Reference `json:"userArnRef,omitempty" tf:"-"`
// Selector for a User in iam to populate userArn.
// +kubebuilder:validation:Optional
UserArnSelector *v1.Selector `json:"userArnSelector,omitempty" tf:"-"`
}
func (*EnvironmentMembershipParameters) DeepCopy ¶
func (in *EnvironmentMembershipParameters) DeepCopy() *EnvironmentMembershipParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EnvironmentMembershipParameters.
func (*EnvironmentMembershipParameters) DeepCopyInto ¶
func (in *EnvironmentMembershipParameters) DeepCopyInto(out *EnvironmentMembershipParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EnvironmentMembershipSpec ¶
type EnvironmentMembershipSpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider EnvironmentMembershipParameters `json:"forProvider"`
}
EnvironmentMembershipSpec defines the desired state of EnvironmentMembership
func (*EnvironmentMembershipSpec) DeepCopy ¶
func (in *EnvironmentMembershipSpec) DeepCopy() *EnvironmentMembershipSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EnvironmentMembershipSpec.
func (*EnvironmentMembershipSpec) DeepCopyInto ¶
func (in *EnvironmentMembershipSpec) DeepCopyInto(out *EnvironmentMembershipSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EnvironmentMembershipStatus ¶
type EnvironmentMembershipStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider EnvironmentMembershipObservation `json:"atProvider,omitempty"`
}
EnvironmentMembershipStatus defines the observed state of EnvironmentMembership.
func (*EnvironmentMembershipStatus) DeepCopy ¶
func (in *EnvironmentMembershipStatus) DeepCopy() *EnvironmentMembershipStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EnvironmentMembershipStatus.
func (*EnvironmentMembershipStatus) DeepCopyInto ¶
func (in *EnvironmentMembershipStatus) DeepCopyInto(out *EnvironmentMembershipStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.