Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +groupName=osis.aws.upbound.io +versionName=v1beta1
Index ¶
- Constants
- Variables
- type BufferOptionsInitParameters
- type BufferOptionsObservation
- type BufferOptionsParameters
- type CloudwatchLogDestinationInitParameters
- type CloudwatchLogDestinationObservation
- type CloudwatchLogDestinationParameters
- type EncryptionAtRestOptionsInitParameters
- type EncryptionAtRestOptionsObservation
- type EncryptionAtRestOptionsParameters
- type LogPublishingOptionsInitParameters
- type LogPublishingOptionsObservation
- type LogPublishingOptionsParameters
- type Pipeline
- func (in *Pipeline) DeepCopy() *Pipeline
- func (in *Pipeline) DeepCopyInto(out *Pipeline)
- func (in *Pipeline) DeepCopyObject() runtime.Object
- func (mg *Pipeline) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *Pipeline) GetConnectionDetailsMapping() map[string]string
- func (mg *Pipeline) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *Pipeline) GetID() string
- func (tr *Pipeline) GetInitParameters() (map[string]any, error)
- func (mg *Pipeline) GetManagementPolicies() xpv1.ManagementPolicies
- func (tr *Pipeline) GetMergedParameters(shouldMergeInitProvider bool) (map[string]any, error)
- func (tr *Pipeline) GetObservation() (map[string]any, error)
- func (tr *Pipeline) GetParameters() (map[string]any, error)
- func (mg *Pipeline) GetProviderConfigReference() *xpv1.Reference
- func (mg *Pipeline) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *Pipeline) GetTerraformResourceType() string
- func (tr *Pipeline) GetTerraformSchemaVersion() int
- func (mg *Pipeline) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *Pipeline) Hub()
- func (tr *Pipeline) LateInitialize(attrs []byte) (bool, error)
- func (mg *Pipeline) SetConditions(c ...xpv1.Condition)
- func (mg *Pipeline) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (mg *Pipeline) SetManagementPolicies(r xpv1.ManagementPolicies)
- func (tr *Pipeline) SetObservation(obs map[string]any) error
- func (tr *Pipeline) SetParameters(params map[string]any) error
- func (mg *Pipeline) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *Pipeline) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *Pipeline) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type PipelineInitParameters
- type PipelineList
- type PipelineObservation
- type PipelineParameters
- type PipelineSpec
- type PipelineStatus
- type VPCOptionsInitParameters
- type VPCOptionsObservation
- type VPCOptionsParameters
Constants ¶
const ( CRDGroup = "osis.aws.upbound.io" CRDVersion = "v1beta1" )
Package type metadata.
Variables ¶
var ( // CRDGroupVersion is the API Group Version used to register the objects CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
var ( Pipeline_Kind = "Pipeline" Pipeline_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: Pipeline_Kind}.String() Pipeline_KindAPIVersion = Pipeline_Kind + "." + CRDGroupVersion.String() Pipeline_GroupVersionKind = CRDGroupVersion.WithKind(Pipeline_Kind) )
Repository type metadata.
Functions ¶
This section is empty.
Types ¶
type BufferOptionsInitParameters ¶
type BufferOptionsInitParameters struct {
// Whether persistent buffering should be enabled.
PersistentBufferEnabled *bool `json:"persistentBufferEnabled,omitempty" tf:"persistent_buffer_enabled,omitempty"`
}
func (*BufferOptionsInitParameters) DeepCopy ¶
func (in *BufferOptionsInitParameters) DeepCopy() *BufferOptionsInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new BufferOptionsInitParameters.
func (*BufferOptionsInitParameters) DeepCopyInto ¶
func (in *BufferOptionsInitParameters) DeepCopyInto(out *BufferOptionsInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type BufferOptionsObservation ¶
type BufferOptionsObservation struct {
// Whether persistent buffering should be enabled.
PersistentBufferEnabled *bool `json:"persistentBufferEnabled,omitempty" tf:"persistent_buffer_enabled,omitempty"`
}
func (*BufferOptionsObservation) DeepCopy ¶
func (in *BufferOptionsObservation) DeepCopy() *BufferOptionsObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new BufferOptionsObservation.
func (*BufferOptionsObservation) DeepCopyInto ¶
func (in *BufferOptionsObservation) DeepCopyInto(out *BufferOptionsObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type BufferOptionsParameters ¶
type BufferOptionsParameters struct {
// Whether persistent buffering should be enabled.
// +kubebuilder:validation:Optional
PersistentBufferEnabled *bool `json:"persistentBufferEnabled" tf:"persistent_buffer_enabled,omitempty"`
}
func (*BufferOptionsParameters) DeepCopy ¶
func (in *BufferOptionsParameters) DeepCopy() *BufferOptionsParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new BufferOptionsParameters.
func (*BufferOptionsParameters) DeepCopyInto ¶
func (in *BufferOptionsParameters) DeepCopyInto(out *BufferOptionsParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CloudwatchLogDestinationInitParameters ¶
type CloudwatchLogDestinationInitParameters struct {
// The name of the CloudWatch Logs group to send pipeline logs to. You can specify an existing log group or create a new one. For example, /aws/OpenSearchService/IngestionService/my-pipeline.
LogGroup *string `json:"logGroup,omitempty" tf:"log_group,omitempty"`
}
func (*CloudwatchLogDestinationInitParameters) DeepCopy ¶
func (in *CloudwatchLogDestinationInitParameters) DeepCopy() *CloudwatchLogDestinationInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CloudwatchLogDestinationInitParameters.
func (*CloudwatchLogDestinationInitParameters) DeepCopyInto ¶
func (in *CloudwatchLogDestinationInitParameters) DeepCopyInto(out *CloudwatchLogDestinationInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CloudwatchLogDestinationObservation ¶
type CloudwatchLogDestinationObservation struct {
// The name of the CloudWatch Logs group to send pipeline logs to. You can specify an existing log group or create a new one. For example, /aws/OpenSearchService/IngestionService/my-pipeline.
LogGroup *string `json:"logGroup,omitempty" tf:"log_group,omitempty"`
}
func (*CloudwatchLogDestinationObservation) DeepCopy ¶
func (in *CloudwatchLogDestinationObservation) DeepCopy() *CloudwatchLogDestinationObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CloudwatchLogDestinationObservation.
func (*CloudwatchLogDestinationObservation) DeepCopyInto ¶
func (in *CloudwatchLogDestinationObservation) DeepCopyInto(out *CloudwatchLogDestinationObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CloudwatchLogDestinationParameters ¶
type CloudwatchLogDestinationParameters struct {
// The name of the CloudWatch Logs group to send pipeline logs to. You can specify an existing log group or create a new one. For example, /aws/OpenSearchService/IngestionService/my-pipeline.
// +kubebuilder:validation:Optional
LogGroup *string `json:"logGroup" tf:"log_group,omitempty"`
}
func (*CloudwatchLogDestinationParameters) DeepCopy ¶
func (in *CloudwatchLogDestinationParameters) DeepCopy() *CloudwatchLogDestinationParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CloudwatchLogDestinationParameters.
func (*CloudwatchLogDestinationParameters) DeepCopyInto ¶
func (in *CloudwatchLogDestinationParameters) DeepCopyInto(out *CloudwatchLogDestinationParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EncryptionAtRestOptionsInitParameters ¶
type EncryptionAtRestOptionsInitParameters struct {
// The ARN of the KMS key used to encrypt data-at-rest in OpenSearch Ingestion. By default, data is encrypted using an AWS owned key.
KMSKeyArn *string `json:"kmsKeyArn,omitempty" tf:"kms_key_arn,omitempty"`
}
func (*EncryptionAtRestOptionsInitParameters) DeepCopy ¶
func (in *EncryptionAtRestOptionsInitParameters) DeepCopy() *EncryptionAtRestOptionsInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EncryptionAtRestOptionsInitParameters.
func (*EncryptionAtRestOptionsInitParameters) DeepCopyInto ¶
func (in *EncryptionAtRestOptionsInitParameters) DeepCopyInto(out *EncryptionAtRestOptionsInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EncryptionAtRestOptionsObservation ¶
type EncryptionAtRestOptionsObservation struct {
// The ARN of the KMS key used to encrypt data-at-rest in OpenSearch Ingestion. By default, data is encrypted using an AWS owned key.
KMSKeyArn *string `json:"kmsKeyArn,omitempty" tf:"kms_key_arn,omitempty"`
}
func (*EncryptionAtRestOptionsObservation) DeepCopy ¶
func (in *EncryptionAtRestOptionsObservation) DeepCopy() *EncryptionAtRestOptionsObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EncryptionAtRestOptionsObservation.
func (*EncryptionAtRestOptionsObservation) DeepCopyInto ¶
func (in *EncryptionAtRestOptionsObservation) DeepCopyInto(out *EncryptionAtRestOptionsObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EncryptionAtRestOptionsParameters ¶
type EncryptionAtRestOptionsParameters struct {
// The ARN of the KMS key used to encrypt data-at-rest in OpenSearch Ingestion. By default, data is encrypted using an AWS owned key.
// +kubebuilder:validation:Optional
KMSKeyArn *string `json:"kmsKeyArn" tf:"kms_key_arn,omitempty"`
}
func (*EncryptionAtRestOptionsParameters) DeepCopy ¶
func (in *EncryptionAtRestOptionsParameters) DeepCopy() *EncryptionAtRestOptionsParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EncryptionAtRestOptionsParameters.
func (*EncryptionAtRestOptionsParameters) DeepCopyInto ¶
func (in *EncryptionAtRestOptionsParameters) DeepCopyInto(out *EncryptionAtRestOptionsParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LogPublishingOptionsInitParameters ¶
type LogPublishingOptionsInitParameters struct {
// The destination for OpenSearch Ingestion logs sent to Amazon CloudWatch Logs. This parameter is required if IsLoggingEnabled is set to true. See cloudwatch_log_destination below.
CloudwatchLogDestination []CloudwatchLogDestinationInitParameters `json:"cloudwatchLogDestination,omitempty" tf:"cloudwatch_log_destination,omitempty"`
// Whether logs should be published.
IsLoggingEnabled *bool `json:"isLoggingEnabled,omitempty" tf:"is_logging_enabled,omitempty"`
}
func (*LogPublishingOptionsInitParameters) DeepCopy ¶
func (in *LogPublishingOptionsInitParameters) DeepCopy() *LogPublishingOptionsInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LogPublishingOptionsInitParameters.
func (*LogPublishingOptionsInitParameters) DeepCopyInto ¶
func (in *LogPublishingOptionsInitParameters) DeepCopyInto(out *LogPublishingOptionsInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LogPublishingOptionsObservation ¶
type LogPublishingOptionsObservation struct {
// The destination for OpenSearch Ingestion logs sent to Amazon CloudWatch Logs. This parameter is required if IsLoggingEnabled is set to true. See cloudwatch_log_destination below.
CloudwatchLogDestination []CloudwatchLogDestinationObservation `json:"cloudwatchLogDestination,omitempty" tf:"cloudwatch_log_destination,omitempty"`
// Whether logs should be published.
IsLoggingEnabled *bool `json:"isLoggingEnabled,omitempty" tf:"is_logging_enabled,omitempty"`
}
func (*LogPublishingOptionsObservation) DeepCopy ¶
func (in *LogPublishingOptionsObservation) DeepCopy() *LogPublishingOptionsObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LogPublishingOptionsObservation.
func (*LogPublishingOptionsObservation) DeepCopyInto ¶
func (in *LogPublishingOptionsObservation) DeepCopyInto(out *LogPublishingOptionsObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LogPublishingOptionsParameters ¶
type LogPublishingOptionsParameters struct {
// The destination for OpenSearch Ingestion logs sent to Amazon CloudWatch Logs. This parameter is required if IsLoggingEnabled is set to true. See cloudwatch_log_destination below.
// +kubebuilder:validation:Optional
CloudwatchLogDestination []CloudwatchLogDestinationParameters `json:"cloudwatchLogDestination,omitempty" tf:"cloudwatch_log_destination,omitempty"`
// Whether logs should be published.
// +kubebuilder:validation:Optional
IsLoggingEnabled *bool `json:"isLoggingEnabled,omitempty" tf:"is_logging_enabled,omitempty"`
}
func (*LogPublishingOptionsParameters) DeepCopy ¶
func (in *LogPublishingOptionsParameters) DeepCopy() *LogPublishingOptionsParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LogPublishingOptionsParameters.
func (*LogPublishingOptionsParameters) DeepCopyInto ¶
func (in *LogPublishingOptionsParameters) DeepCopyInto(out *LogPublishingOptionsParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Pipeline ¶
type Pipeline struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.maxUnits) || (has(self.initProvider) && has(self.initProvider.maxUnits))",message="spec.forProvider.maxUnits is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.minUnits) || (has(self.initProvider) && has(self.initProvider.minUnits))",message="spec.forProvider.minUnits is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.pipelineConfigurationBody) || (has(self.initProvider) && has(self.initProvider.pipelineConfigurationBody))",message="spec.forProvider.pipelineConfigurationBody is a required parameter"
Spec PipelineSpec `json:"spec"`
Status PipelineStatus `json:"status,omitempty"`
}
Pipeline is the Schema for the Pipelines API. +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,aws}
func (*Pipeline) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Pipeline.
func (*Pipeline) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Pipeline) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*Pipeline) GetCondition ¶
func (mg *Pipeline) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this Pipeline.
func (*Pipeline) GetConnectionDetailsMapping ¶
GetConnectionDetailsMapping for this Pipeline
func (*Pipeline) GetDeletionPolicy ¶
func (mg *Pipeline) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this Pipeline.
func (*Pipeline) GetInitParameters ¶
GetInitParameters of this Pipeline
func (*Pipeline) GetManagementPolicies ¶
func (mg *Pipeline) GetManagementPolicies() xpv1.ManagementPolicies
GetManagementPolicies of this Pipeline.
func (*Pipeline) GetMergedParameters ¶
GetInitParameters of this Pipeline
func (*Pipeline) GetObservation ¶
GetObservation of this Pipeline
func (*Pipeline) GetParameters ¶
GetParameters of this Pipeline
func (*Pipeline) GetProviderConfigReference ¶
GetProviderConfigReference of this Pipeline.
func (*Pipeline) GetPublishConnectionDetailsTo ¶
func (mg *Pipeline) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this Pipeline.
func (*Pipeline) GetTerraformResourceType ¶
GetTerraformResourceType returns Terraform resource type for this Pipeline
func (*Pipeline) GetTerraformSchemaVersion ¶
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*Pipeline) GetWriteConnectionSecretToReference ¶
func (mg *Pipeline) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this Pipeline.
func (*Pipeline) LateInitialize ¶
LateInitialize this Pipeline using its observed tfState. returns True if there are any spec changes for the resource.
func (*Pipeline) SetConditions ¶
SetConditions of this Pipeline.
func (*Pipeline) SetDeletionPolicy ¶
func (mg *Pipeline) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this Pipeline.
func (*Pipeline) SetManagementPolicies ¶
func (mg *Pipeline) SetManagementPolicies(r xpv1.ManagementPolicies)
SetManagementPolicies of this Pipeline.
func (*Pipeline) SetObservation ¶
SetObservation for this Pipeline
func (*Pipeline) SetParameters ¶
SetParameters for this Pipeline
func (*Pipeline) SetProviderConfigReference ¶
SetProviderConfigReference of this Pipeline.
func (*Pipeline) SetPublishConnectionDetailsTo ¶
func (mg *Pipeline) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this Pipeline.
func (*Pipeline) SetWriteConnectionSecretToReference ¶
func (mg *Pipeline) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this Pipeline.
type PipelineInitParameters ¶
type PipelineInitParameters struct {
// Key-value pairs to configure persistent buffering for the pipeline. See buffer_options below.
BufferOptions []BufferOptionsInitParameters `json:"bufferOptions,omitempty" tf:"buffer_options,omitempty"`
// Key-value pairs to configure encryption for data that is written to a persistent buffer. See encryption_at_rest_options below.
EncryptionAtRestOptions []EncryptionAtRestOptionsInitParameters `json:"encryptionAtRestOptions,omitempty" tf:"encryption_at_rest_options,omitempty"`
// Key-value pairs to configure log publishing. See log_publishing_options below.
LogPublishingOptions []LogPublishingOptionsInitParameters `json:"logPublishingOptions,omitempty" tf:"log_publishing_options,omitempty"`
// The maximum pipeline capacity, in Ingestion Compute Units (ICUs).
MaxUnits *float64 `json:"maxUnits,omitempty" tf:"max_units,omitempty"`
// The minimum pipeline capacity, in Ingestion Compute Units (ICUs).
MinUnits *float64 `json:"minUnits,omitempty" tf:"min_units,omitempty"`
// The pipeline configuration in YAML format. This argument accepts the pipeline configuration as a string or within a .yaml file. If you provide the configuration as a string, each new line must be escaped with \n.
PipelineConfigurationBody *string `json:"pipelineConfigurationBody,omitempty" tf:"pipeline_configuration_body,omitempty"`
// Key-value map of resource tags.
// +mapType=granular
Tags map[string]*string `json:"tags,omitempty" tf:"tags,omitempty"`
// Container for the values required to configure VPC access for the pipeline. If you don't specify these values, OpenSearch Ingestion creates the pipeline with a public endpoint. See vpc_options below.
VPCOptions []VPCOptionsInitParameters `json:"vpcOptions,omitempty" tf:"vpc_options,omitempty"`
}
func (*PipelineInitParameters) DeepCopy ¶
func (in *PipelineInitParameters) DeepCopy() *PipelineInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PipelineInitParameters.
func (*PipelineInitParameters) DeepCopyInto ¶
func (in *PipelineInitParameters) DeepCopyInto(out *PipelineInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PipelineList ¶
type PipelineList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Pipeline `json:"items"`
}
PipelineList contains a list of Pipelines
func (*PipelineList) DeepCopy ¶
func (in *PipelineList) DeepCopy() *PipelineList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PipelineList.
func (*PipelineList) DeepCopyInto ¶
func (in *PipelineList) DeepCopyInto(out *PipelineList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*PipelineList) DeepCopyObject ¶
func (in *PipelineList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*PipelineList) GetItems ¶
func (l *PipelineList) GetItems() []resource.Managed
GetItems of this PipelineList.
type PipelineObservation ¶
type PipelineObservation struct {
// Key-value pairs to configure persistent buffering for the pipeline. See buffer_options below.
BufferOptions []BufferOptionsObservation `json:"bufferOptions,omitempty" tf:"buffer_options,omitempty"`
// Key-value pairs to configure encryption for data that is written to a persistent buffer. See encryption_at_rest_options below.
EncryptionAtRestOptions []EncryptionAtRestOptionsObservation `json:"encryptionAtRestOptions,omitempty" tf:"encryption_at_rest_options,omitempty"`
// Unique identifier for the pipeline.
ID *string `json:"id,omitempty" tf:"id,omitempty"`
// The list of ingestion endpoints for the pipeline, which you can send data to.
// +listType=set
IngestEndpointUrls []*string `json:"ingestEndpointUrls,omitempty" tf:"ingest_endpoint_urls,omitempty"`
// Key-value pairs to configure log publishing. See log_publishing_options below.
LogPublishingOptions []LogPublishingOptionsObservation `json:"logPublishingOptions,omitempty" tf:"log_publishing_options,omitempty"`
// The maximum pipeline capacity, in Ingestion Compute Units (ICUs).
MaxUnits *float64 `json:"maxUnits,omitempty" tf:"max_units,omitempty"`
// The minimum pipeline capacity, in Ingestion Compute Units (ICUs).
MinUnits *float64 `json:"minUnits,omitempty" tf:"min_units,omitempty"`
// Amazon Resource Name (ARN) of the pipeline.
PipelineArn *string `json:"pipelineArn,omitempty" tf:"pipeline_arn,omitempty"`
// The pipeline configuration in YAML format. This argument accepts the pipeline configuration as a string or within a .yaml file. If you provide the configuration as a string, each new line must be escaped with \n.
PipelineConfigurationBody *string `json:"pipelineConfigurationBody,omitempty" tf:"pipeline_configuration_body,omitempty"`
// Key-value map of resource tags.
// +mapType=granular
Tags map[string]*string `json:"tags,omitempty" tf:"tags,omitempty"`
// +mapType=granular
TagsAll map[string]*string `json:"tagsAll,omitempty" tf:"tags_all,omitempty"`
// Container for the values required to configure VPC access for the pipeline. If you don't specify these values, OpenSearch Ingestion creates the pipeline with a public endpoint. See vpc_options below.
VPCOptions []VPCOptionsObservation `json:"vpcOptions,omitempty" tf:"vpc_options,omitempty"`
}
func (*PipelineObservation) DeepCopy ¶
func (in *PipelineObservation) DeepCopy() *PipelineObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PipelineObservation.
func (*PipelineObservation) DeepCopyInto ¶
func (in *PipelineObservation) DeepCopyInto(out *PipelineObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PipelineParameters ¶
type PipelineParameters struct {
// Key-value pairs to configure persistent buffering for the pipeline. See buffer_options below.
// +kubebuilder:validation:Optional
BufferOptions []BufferOptionsParameters `json:"bufferOptions,omitempty" tf:"buffer_options,omitempty"`
// Key-value pairs to configure encryption for data that is written to a persistent buffer. See encryption_at_rest_options below.
// +kubebuilder:validation:Optional
EncryptionAtRestOptions []EncryptionAtRestOptionsParameters `json:"encryptionAtRestOptions,omitempty" tf:"encryption_at_rest_options,omitempty"`
// Key-value pairs to configure log publishing. See log_publishing_options below.
// +kubebuilder:validation:Optional
LogPublishingOptions []LogPublishingOptionsParameters `json:"logPublishingOptions,omitempty" tf:"log_publishing_options,omitempty"`
// The maximum pipeline capacity, in Ingestion Compute Units (ICUs).
// +kubebuilder:validation:Optional
MaxUnits *float64 `json:"maxUnits,omitempty" tf:"max_units,omitempty"`
// The minimum pipeline capacity, in Ingestion Compute Units (ICUs).
// +kubebuilder:validation:Optional
MinUnits *float64 `json:"minUnits,omitempty" tf:"min_units,omitempty"`
// The pipeline configuration in YAML format. This argument accepts the pipeline configuration as a string or within a .yaml file. If you provide the configuration as a string, each new line must be escaped with \n.
// +kubebuilder:validation:Optional
PipelineConfigurationBody *string `json:"pipelineConfigurationBody,omitempty" tf:"pipeline_configuration_body,omitempty"`
// Region is the region you'd like your resource to be created in.
// +upjet:crd:field:TFTag=-
// +kubebuilder:validation:Required
Region *string `json:"region" tf:"-"`
// Key-value map of resource tags.
// +kubebuilder:validation:Optional
// +mapType=granular
Tags map[string]*string `json:"tags,omitempty" tf:"tags,omitempty"`
// Container for the values required to configure VPC access for the pipeline. If you don't specify these values, OpenSearch Ingestion creates the pipeline with a public endpoint. See vpc_options below.
// +kubebuilder:validation:Optional
VPCOptions []VPCOptionsParameters `json:"vpcOptions,omitempty" tf:"vpc_options,omitempty"`
}
func (*PipelineParameters) DeepCopy ¶
func (in *PipelineParameters) DeepCopy() *PipelineParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PipelineParameters.
func (*PipelineParameters) DeepCopyInto ¶
func (in *PipelineParameters) DeepCopyInto(out *PipelineParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PipelineSpec ¶
type PipelineSpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider PipelineParameters `json:"forProvider"`
// THIS IS A BETA FIELD. It will be honored
// unless the Management Policies feature flag is disabled.
// InitProvider holds the same fields as ForProvider, with the exception
// of Identifier and other resource reference fields. The fields that are
// in InitProvider are merged into ForProvider when the resource is created.
// The same fields are also added to the terraform ignore_changes hook, to
// avoid updating them after creation. This is useful for fields that are
// required on creation, but we do not desire to update them after creation,
// for example because of an external controller is managing them, like an
// autoscaler.
InitProvider PipelineInitParameters `json:"initProvider,omitempty"`
}
PipelineSpec defines the desired state of Pipeline
func (*PipelineSpec) DeepCopy ¶
func (in *PipelineSpec) DeepCopy() *PipelineSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PipelineSpec.
func (*PipelineSpec) DeepCopyInto ¶
func (in *PipelineSpec) DeepCopyInto(out *PipelineSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PipelineStatus ¶
type PipelineStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider PipelineObservation `json:"atProvider,omitempty"`
}
PipelineStatus defines the observed state of Pipeline.
func (*PipelineStatus) DeepCopy ¶
func (in *PipelineStatus) DeepCopy() *PipelineStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PipelineStatus.
func (*PipelineStatus) DeepCopyInto ¶
func (in *PipelineStatus) DeepCopyInto(out *PipelineStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type VPCOptionsInitParameters ¶
type VPCOptionsInitParameters struct {
// A list of security groups associated with the VPC endpoint.
// +listType=set
SecurityGroupIds []*string `json:"securityGroupIds,omitempty" tf:"security_group_ids,omitempty"`
// A list of subnet IDs associated with the VPC endpoint.
// +listType=set
SubnetIds []*string `json:"subnetIds,omitempty" tf:"subnet_ids,omitempty"`
}
func (*VPCOptionsInitParameters) DeepCopy ¶
func (in *VPCOptionsInitParameters) DeepCopy() *VPCOptionsInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VPCOptionsInitParameters.
func (*VPCOptionsInitParameters) DeepCopyInto ¶
func (in *VPCOptionsInitParameters) DeepCopyInto(out *VPCOptionsInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type VPCOptionsObservation ¶
type VPCOptionsObservation struct {
// A list of security groups associated with the VPC endpoint.
// +listType=set
SecurityGroupIds []*string `json:"securityGroupIds,omitempty" tf:"security_group_ids,omitempty"`
// A list of subnet IDs associated with the VPC endpoint.
// +listType=set
SubnetIds []*string `json:"subnetIds,omitempty" tf:"subnet_ids,omitempty"`
}
func (*VPCOptionsObservation) DeepCopy ¶
func (in *VPCOptionsObservation) DeepCopy() *VPCOptionsObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VPCOptionsObservation.
func (*VPCOptionsObservation) DeepCopyInto ¶
func (in *VPCOptionsObservation) DeepCopyInto(out *VPCOptionsObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type VPCOptionsParameters ¶
type VPCOptionsParameters struct {
// A list of security groups associated with the VPC endpoint.
// +kubebuilder:validation:Optional
// +listType=set
SecurityGroupIds []*string `json:"securityGroupIds,omitempty" tf:"security_group_ids,omitempty"`
// A list of subnet IDs associated with the VPC endpoint.
// +kubebuilder:validation:Optional
// +listType=set
SubnetIds []*string `json:"subnetIds" tf:"subnet_ids,omitempty"`
}
func (*VPCOptionsParameters) DeepCopy ¶
func (in *VPCOptionsParameters) DeepCopy() *VPCOptionsParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VPCOptionsParameters.
func (*VPCOptionsParameters) DeepCopyInto ¶
func (in *VPCOptionsParameters) DeepCopyInto(out *VPCOptionsParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.