Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +groupName=ses.aws.upbound.io +versionName=v1beta2
Index ¶
- Constants
- Variables
- type CloudwatchDestinationInitParameters
- type CloudwatchDestinationObservation
- type CloudwatchDestinationParameters
- type ConfigurationSet
- func (in *ConfigurationSet) DeepCopy() *ConfigurationSet
- func (in *ConfigurationSet) DeepCopyInto(out *ConfigurationSet)
- func (in *ConfigurationSet) DeepCopyObject() runtime.Object
- func (mg *ConfigurationSet) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *ConfigurationSet) GetConnectionDetailsMapping() map[string]string
- func (mg *ConfigurationSet) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *ConfigurationSet) GetID() string
- func (tr *ConfigurationSet) GetInitParameters() (map[string]any, error)
- func (mg *ConfigurationSet) GetManagementPolicies() xpv1.ManagementPolicies
- func (tr *ConfigurationSet) GetMergedParameters(shouldMergeInitProvider bool) (map[string]any, error)
- func (tr *ConfigurationSet) GetObservation() (map[string]any, error)
- func (tr *ConfigurationSet) GetParameters() (map[string]any, error)
- func (mg *ConfigurationSet) GetProviderConfigReference() *xpv1.Reference
- func (mg *ConfigurationSet) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *ConfigurationSet) GetTerraformResourceType() string
- func (tr *ConfigurationSet) GetTerraformSchemaVersion() int
- func (mg *ConfigurationSet) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *ConfigurationSet) Hub()
- func (tr *ConfigurationSet) LateInitialize(attrs []byte) (bool, error)
- func (mg *ConfigurationSet) SetConditions(c ...xpv1.Condition)
- func (mg *ConfigurationSet) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (mg *ConfigurationSet) SetManagementPolicies(r xpv1.ManagementPolicies)
- func (tr *ConfigurationSet) SetObservation(obs map[string]any) error
- func (tr *ConfigurationSet) SetParameters(params map[string]any) error
- func (mg *ConfigurationSet) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *ConfigurationSet) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *ConfigurationSet) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type ConfigurationSetInitParameters
- type ConfigurationSetList
- type ConfigurationSetObservation
- type ConfigurationSetParameters
- type ConfigurationSetSpec
- type ConfigurationSetStatus
- type DeliveryOptionsInitParameters
- type DeliveryOptionsObservation
- type DeliveryOptionsParameters
- type EventDestination
- func (in *EventDestination) DeepCopy() *EventDestination
- func (in *EventDestination) DeepCopyInto(out *EventDestination)
- func (in *EventDestination) DeepCopyObject() runtime.Object
- func (mg *EventDestination) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *EventDestination) GetConnectionDetailsMapping() map[string]string
- func (mg *EventDestination) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *EventDestination) GetID() string
- func (tr *EventDestination) GetInitParameters() (map[string]any, error)
- func (mg *EventDestination) GetManagementPolicies() xpv1.ManagementPolicies
- func (tr *EventDestination) GetMergedParameters(shouldMergeInitProvider bool) (map[string]any, error)
- func (tr *EventDestination) GetObservation() (map[string]any, error)
- func (tr *EventDestination) GetParameters() (map[string]any, error)
- func (mg *EventDestination) GetProviderConfigReference() *xpv1.Reference
- func (mg *EventDestination) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *EventDestination) GetTerraformResourceType() string
- func (tr *EventDestination) GetTerraformSchemaVersion() int
- func (mg *EventDestination) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *EventDestination) Hub()
- func (tr *EventDestination) LateInitialize(attrs []byte) (bool, error)
- func (mg *EventDestination) ResolveReferences(ctx context.Context, c client.Reader) error
- func (mg *EventDestination) SetConditions(c ...xpv1.Condition)
- func (mg *EventDestination) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (mg *EventDestination) SetManagementPolicies(r xpv1.ManagementPolicies)
- func (tr *EventDestination) SetObservation(obs map[string]any) error
- func (tr *EventDestination) SetParameters(params map[string]any) error
- func (mg *EventDestination) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *EventDestination) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *EventDestination) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type EventDestinationInitParameters
- type EventDestinationList
- type EventDestinationObservation
- type EventDestinationParameters
- type EventDestinationSpec
- type EventDestinationStatus
- type KinesisDestinationInitParameters
- type KinesisDestinationObservation
- type KinesisDestinationParameters
- type SnsDestinationInitParameters
- type SnsDestinationObservation
- type SnsDestinationParameters
- type TrackingOptionsInitParameters
- type TrackingOptionsObservation
- type TrackingOptionsParameters
Constants ¶
const ( CRDGroup = "ses.aws.upbound.io" CRDVersion = "v1beta2" )
Package type metadata.
Variables ¶
var ( ConfigurationSet_Kind = "ConfigurationSet" ConfigurationSet_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: ConfigurationSet_Kind}.String() ConfigurationSet_KindAPIVersion = ConfigurationSet_Kind + "." + CRDGroupVersion.String() ConfigurationSet_GroupVersionKind = CRDGroupVersion.WithKind(ConfigurationSet_Kind) )
Repository type metadata.
var ( EventDestination_Kind = "EventDestination" EventDestination_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: EventDestination_Kind}.String() EventDestination_KindAPIVersion = EventDestination_Kind + "." + CRDGroupVersion.String() EventDestination_GroupVersionKind = CRDGroupVersion.WithKind(EventDestination_Kind) )
Repository type metadata.
var ( // CRDGroupVersion is the API Group Version used to register the objects CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type CloudwatchDestinationInitParameters ¶
type CloudwatchDestinationInitParameters struct {
// The default value for the event
DefaultValue *string `json:"defaultValue,omitempty" tf:"default_value,omitempty"`
// The name for the dimension
DimensionName *string `json:"dimensionName,omitempty" tf:"dimension_name,omitempty"`
// The source for the value. May be any of "messageTag", "emailHeader" or "linkTag".
ValueSource *string `json:"valueSource,omitempty" tf:"value_source,omitempty"`
}
func (*CloudwatchDestinationInitParameters) DeepCopy ¶
func (in *CloudwatchDestinationInitParameters) DeepCopy() *CloudwatchDestinationInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CloudwatchDestinationInitParameters.
func (*CloudwatchDestinationInitParameters) DeepCopyInto ¶
func (in *CloudwatchDestinationInitParameters) DeepCopyInto(out *CloudwatchDestinationInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CloudwatchDestinationObservation ¶
type CloudwatchDestinationObservation struct {
// The default value for the event
DefaultValue *string `json:"defaultValue,omitempty" tf:"default_value,omitempty"`
// The name for the dimension
DimensionName *string `json:"dimensionName,omitempty" tf:"dimension_name,omitempty"`
// The source for the value. May be any of "messageTag", "emailHeader" or "linkTag".
ValueSource *string `json:"valueSource,omitempty" tf:"value_source,omitempty"`
}
func (*CloudwatchDestinationObservation) DeepCopy ¶
func (in *CloudwatchDestinationObservation) DeepCopy() *CloudwatchDestinationObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CloudwatchDestinationObservation.
func (*CloudwatchDestinationObservation) DeepCopyInto ¶
func (in *CloudwatchDestinationObservation) DeepCopyInto(out *CloudwatchDestinationObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CloudwatchDestinationParameters ¶
type CloudwatchDestinationParameters struct {
// The default value for the event
// +kubebuilder:validation:Optional
DefaultValue *string `json:"defaultValue" tf:"default_value,omitempty"`
// The name for the dimension
// +kubebuilder:validation:Optional
DimensionName *string `json:"dimensionName" tf:"dimension_name,omitempty"`
// The source for the value. May be any of "messageTag", "emailHeader" or "linkTag".
// +kubebuilder:validation:Optional
ValueSource *string `json:"valueSource" tf:"value_source,omitempty"`
}
func (*CloudwatchDestinationParameters) DeepCopy ¶
func (in *CloudwatchDestinationParameters) DeepCopy() *CloudwatchDestinationParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CloudwatchDestinationParameters.
func (*CloudwatchDestinationParameters) DeepCopyInto ¶
func (in *CloudwatchDestinationParameters) DeepCopyInto(out *CloudwatchDestinationParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ConfigurationSet ¶
type ConfigurationSet struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec ConfigurationSetSpec `json:"spec"`
Status ConfigurationSetStatus `json:"status,omitempty"`
}
ConfigurationSet is the Schema for the ConfigurationSets API. Provides an SES configuration set +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,aws}
func (*ConfigurationSet) DeepCopy ¶
func (in *ConfigurationSet) DeepCopy() *ConfigurationSet
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ConfigurationSet.
func (*ConfigurationSet) DeepCopyInto ¶
func (in *ConfigurationSet) DeepCopyInto(out *ConfigurationSet)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ConfigurationSet) DeepCopyObject ¶
func (in *ConfigurationSet) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*ConfigurationSet) GetCondition ¶
func (mg *ConfigurationSet) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this ConfigurationSet.
func (*ConfigurationSet) GetConnectionDetailsMapping ¶
func (tr *ConfigurationSet) GetConnectionDetailsMapping() map[string]string
GetConnectionDetailsMapping for this ConfigurationSet
func (*ConfigurationSet) GetDeletionPolicy ¶
func (mg *ConfigurationSet) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this ConfigurationSet.
func (*ConfigurationSet) GetID ¶
func (tr *ConfigurationSet) GetID() string
GetID returns ID of underlying Terraform resource of this ConfigurationSet
func (*ConfigurationSet) GetInitParameters ¶
func (tr *ConfigurationSet) GetInitParameters() (map[string]any, error)
GetInitParameters of this ConfigurationSet
func (*ConfigurationSet) GetManagementPolicies ¶
func (mg *ConfigurationSet) GetManagementPolicies() xpv1.ManagementPolicies
GetManagementPolicies of this ConfigurationSet.
func (*ConfigurationSet) GetMergedParameters ¶
func (tr *ConfigurationSet) GetMergedParameters(shouldMergeInitProvider bool) (map[string]any, error)
GetInitParameters of this ConfigurationSet
func (*ConfigurationSet) GetObservation ¶
func (tr *ConfigurationSet) GetObservation() (map[string]any, error)
GetObservation of this ConfigurationSet
func (*ConfigurationSet) GetParameters ¶
func (tr *ConfigurationSet) GetParameters() (map[string]any, error)
GetParameters of this ConfigurationSet
func (*ConfigurationSet) GetProviderConfigReference ¶
func (mg *ConfigurationSet) GetProviderConfigReference() *xpv1.Reference
GetProviderConfigReference of this ConfigurationSet.
func (*ConfigurationSet) GetPublishConnectionDetailsTo ¶
func (mg *ConfigurationSet) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this ConfigurationSet.
func (*ConfigurationSet) GetTerraformResourceType ¶
func (mg *ConfigurationSet) GetTerraformResourceType() string
GetTerraformResourceType returns Terraform resource type for this ConfigurationSet
func (*ConfigurationSet) GetTerraformSchemaVersion ¶
func (tr *ConfigurationSet) GetTerraformSchemaVersion() int
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*ConfigurationSet) GetWriteConnectionSecretToReference ¶
func (mg *ConfigurationSet) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this ConfigurationSet.
func (*ConfigurationSet) Hub ¶
func (tr *ConfigurationSet) Hub()
Hub marks this type as a conversion hub.
func (*ConfigurationSet) LateInitialize ¶
func (tr *ConfigurationSet) LateInitialize(attrs []byte) (bool, error)
LateInitialize this ConfigurationSet using its observed tfState. returns True if there are any spec changes for the resource.
func (*ConfigurationSet) SetConditions ¶
func (mg *ConfigurationSet) SetConditions(c ...xpv1.Condition)
SetConditions of this ConfigurationSet.
func (*ConfigurationSet) SetDeletionPolicy ¶
func (mg *ConfigurationSet) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this ConfigurationSet.
func (*ConfigurationSet) SetManagementPolicies ¶
func (mg *ConfigurationSet) SetManagementPolicies(r xpv1.ManagementPolicies)
SetManagementPolicies of this ConfigurationSet.
func (*ConfigurationSet) SetObservation ¶
func (tr *ConfigurationSet) SetObservation(obs map[string]any) error
SetObservation for this ConfigurationSet
func (*ConfigurationSet) SetParameters ¶
func (tr *ConfigurationSet) SetParameters(params map[string]any) error
SetParameters for this ConfigurationSet
func (*ConfigurationSet) SetProviderConfigReference ¶
func (mg *ConfigurationSet) SetProviderConfigReference(r *xpv1.Reference)
SetProviderConfigReference of this ConfigurationSet.
func (*ConfigurationSet) SetPublishConnectionDetailsTo ¶
func (mg *ConfigurationSet) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this ConfigurationSet.
func (*ConfigurationSet) SetWriteConnectionSecretToReference ¶
func (mg *ConfigurationSet) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this ConfigurationSet.
type ConfigurationSetInitParameters ¶
type ConfigurationSetInitParameters struct {
// Whether messages that use the configuration set are required to use TLS. See below.
DeliveryOptions *DeliveryOptionsInitParameters `json:"deliveryOptions,omitempty" tf:"delivery_options,omitempty"`
// Whether or not Amazon SES publishes reputation metrics for the configuration set, such as bounce and complaint rates, to Amazon CloudWatch. The default value is false.
ReputationMetricsEnabled *bool `json:"reputationMetricsEnabled,omitempty" tf:"reputation_metrics_enabled,omitempty"`
// Whether email sending is enabled or disabled for the configuration set. The default value is true.
SendingEnabled *bool `json:"sendingEnabled,omitempty" tf:"sending_enabled,omitempty"`
// Domain that is used to redirect email recipients to an Amazon SES-operated domain. See below. NOTE: This functionality is best effort.
TrackingOptions *TrackingOptionsInitParameters `json:"trackingOptions,omitempty" tf:"tracking_options,omitempty"`
}
func (*ConfigurationSetInitParameters) DeepCopy ¶
func (in *ConfigurationSetInitParameters) DeepCopy() *ConfigurationSetInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ConfigurationSetInitParameters.
func (*ConfigurationSetInitParameters) DeepCopyInto ¶
func (in *ConfigurationSetInitParameters) DeepCopyInto(out *ConfigurationSetInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ConfigurationSetList ¶
type ConfigurationSetList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []ConfigurationSet `json:"items"`
}
ConfigurationSetList contains a list of ConfigurationSets
func (*ConfigurationSetList) DeepCopy ¶
func (in *ConfigurationSetList) DeepCopy() *ConfigurationSetList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ConfigurationSetList.
func (*ConfigurationSetList) DeepCopyInto ¶
func (in *ConfigurationSetList) DeepCopyInto(out *ConfigurationSetList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ConfigurationSetList) DeepCopyObject ¶
func (in *ConfigurationSetList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*ConfigurationSetList) GetItems ¶
func (l *ConfigurationSetList) GetItems() []resource.Managed
GetItems of this ConfigurationSetList.
type ConfigurationSetObservation ¶
type ConfigurationSetObservation struct {
// SES configuration set ARN.
Arn *string `json:"arn,omitempty" tf:"arn,omitempty"`
// Whether messages that use the configuration set are required to use TLS. See below.
DeliveryOptions *DeliveryOptionsObservation `json:"deliveryOptions,omitempty" tf:"delivery_options,omitempty"`
// SES configuration set name.
ID *string `json:"id,omitempty" tf:"id,omitempty"`
// Date and time at which the reputation metrics for the configuration set were last reset. Resetting these metrics is known as a fresh start.
LastFreshStart *string `json:"lastFreshStart,omitempty" tf:"last_fresh_start,omitempty"`
// Whether or not Amazon SES publishes reputation metrics for the configuration set, such as bounce and complaint rates, to Amazon CloudWatch. The default value is false.
ReputationMetricsEnabled *bool `json:"reputationMetricsEnabled,omitempty" tf:"reputation_metrics_enabled,omitempty"`
// Whether email sending is enabled or disabled for the configuration set. The default value is true.
SendingEnabled *bool `json:"sendingEnabled,omitempty" tf:"sending_enabled,omitempty"`
// Domain that is used to redirect email recipients to an Amazon SES-operated domain. See below. NOTE: This functionality is best effort.
TrackingOptions *TrackingOptionsObservation `json:"trackingOptions,omitempty" tf:"tracking_options,omitempty"`
}
func (*ConfigurationSetObservation) DeepCopy ¶
func (in *ConfigurationSetObservation) DeepCopy() *ConfigurationSetObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ConfigurationSetObservation.
func (*ConfigurationSetObservation) DeepCopyInto ¶
func (in *ConfigurationSetObservation) DeepCopyInto(out *ConfigurationSetObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ConfigurationSetParameters ¶
type ConfigurationSetParameters struct {
// Whether messages that use the configuration set are required to use TLS. See below.
// +kubebuilder:validation:Optional
DeliveryOptions *DeliveryOptionsParameters `json:"deliveryOptions,omitempty" tf:"delivery_options,omitempty"`
// Region is the region you'd like your resource to be created in.
// +upjet:crd:field:TFTag=-
// +kubebuilder:validation:Required
Region *string `json:"region" tf:"-"`
// Whether or not Amazon SES publishes reputation metrics for the configuration set, such as bounce and complaint rates, to Amazon CloudWatch. The default value is false.
// +kubebuilder:validation:Optional
ReputationMetricsEnabled *bool `json:"reputationMetricsEnabled,omitempty" tf:"reputation_metrics_enabled,omitempty"`
// Whether email sending is enabled or disabled for the configuration set. The default value is true.
// +kubebuilder:validation:Optional
SendingEnabled *bool `json:"sendingEnabled,omitempty" tf:"sending_enabled,omitempty"`
// Domain that is used to redirect email recipients to an Amazon SES-operated domain. See below. NOTE: This functionality is best effort.
// +kubebuilder:validation:Optional
TrackingOptions *TrackingOptionsParameters `json:"trackingOptions,omitempty" tf:"tracking_options,omitempty"`
}
func (*ConfigurationSetParameters) DeepCopy ¶
func (in *ConfigurationSetParameters) DeepCopy() *ConfigurationSetParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ConfigurationSetParameters.
func (*ConfigurationSetParameters) DeepCopyInto ¶
func (in *ConfigurationSetParameters) DeepCopyInto(out *ConfigurationSetParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ConfigurationSetSpec ¶
type ConfigurationSetSpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider ConfigurationSetParameters `json:"forProvider"`
// THIS IS A BETA FIELD. It will be honored
// unless the Management Policies feature flag is disabled.
// InitProvider holds the same fields as ForProvider, with the exception
// of Identifier and other resource reference fields. The fields that are
// in InitProvider are merged into ForProvider when the resource is created.
// The same fields are also added to the terraform ignore_changes hook, to
// avoid updating them after creation. This is useful for fields that are
// required on creation, but we do not desire to update them after creation,
// for example because of an external controller is managing them, like an
// autoscaler.
InitProvider ConfigurationSetInitParameters `json:"initProvider,omitempty"`
}
ConfigurationSetSpec defines the desired state of ConfigurationSet
func (*ConfigurationSetSpec) DeepCopy ¶
func (in *ConfigurationSetSpec) DeepCopy() *ConfigurationSetSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ConfigurationSetSpec.
func (*ConfigurationSetSpec) DeepCopyInto ¶
func (in *ConfigurationSetSpec) DeepCopyInto(out *ConfigurationSetSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ConfigurationSetStatus ¶
type ConfigurationSetStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider ConfigurationSetObservation `json:"atProvider,omitempty"`
}
ConfigurationSetStatus defines the observed state of ConfigurationSet.
func (*ConfigurationSetStatus) DeepCopy ¶
func (in *ConfigurationSetStatus) DeepCopy() *ConfigurationSetStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ConfigurationSetStatus.
func (*ConfigurationSetStatus) DeepCopyInto ¶
func (in *ConfigurationSetStatus) DeepCopyInto(out *ConfigurationSetStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DeliveryOptionsInitParameters ¶
type DeliveryOptionsInitParameters struct {
// Whether messages that use the configuration set are required to use Transport Layer Security (TLS). If the value is Require, messages are only delivered if a TLS connection can be established. If the value is Optional, messages can be delivered in plain text if a TLS connection can't be established. Valid values: Require or Optional. Defaults to Optional.
TLSPolicy *string `json:"tlsPolicy,omitempty" tf:"tls_policy,omitempty"`
}
func (*DeliveryOptionsInitParameters) DeepCopy ¶
func (in *DeliveryOptionsInitParameters) DeepCopy() *DeliveryOptionsInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DeliveryOptionsInitParameters.
func (*DeliveryOptionsInitParameters) DeepCopyInto ¶
func (in *DeliveryOptionsInitParameters) DeepCopyInto(out *DeliveryOptionsInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DeliveryOptionsObservation ¶
type DeliveryOptionsObservation struct {
// Whether messages that use the configuration set are required to use Transport Layer Security (TLS). If the value is Require, messages are only delivered if a TLS connection can be established. If the value is Optional, messages can be delivered in plain text if a TLS connection can't be established. Valid values: Require or Optional. Defaults to Optional.
TLSPolicy *string `json:"tlsPolicy,omitempty" tf:"tls_policy,omitempty"`
}
func (*DeliveryOptionsObservation) DeepCopy ¶
func (in *DeliveryOptionsObservation) DeepCopy() *DeliveryOptionsObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DeliveryOptionsObservation.
func (*DeliveryOptionsObservation) DeepCopyInto ¶
func (in *DeliveryOptionsObservation) DeepCopyInto(out *DeliveryOptionsObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DeliveryOptionsParameters ¶
type DeliveryOptionsParameters struct {
// Whether messages that use the configuration set are required to use Transport Layer Security (TLS). If the value is Require, messages are only delivered if a TLS connection can be established. If the value is Optional, messages can be delivered in plain text if a TLS connection can't be established. Valid values: Require or Optional. Defaults to Optional.
// +kubebuilder:validation:Optional
TLSPolicy *string `json:"tlsPolicy,omitempty" tf:"tls_policy,omitempty"`
}
func (*DeliveryOptionsParameters) DeepCopy ¶
func (in *DeliveryOptionsParameters) DeepCopy() *DeliveryOptionsParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DeliveryOptionsParameters.
func (*DeliveryOptionsParameters) DeepCopyInto ¶
func (in *DeliveryOptionsParameters) DeepCopyInto(out *DeliveryOptionsParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EventDestination ¶
type EventDestination struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.matchingTypes) || (has(self.initProvider) && has(self.initProvider.matchingTypes))",message="spec.forProvider.matchingTypes is a required parameter"
Spec EventDestinationSpec `json:"spec"`
Status EventDestinationStatus `json:"status,omitempty"`
}
EventDestination is the Schema for the EventDestinations API. Provides an SES event destination +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,aws}
func (*EventDestination) DeepCopy ¶
func (in *EventDestination) DeepCopy() *EventDestination
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventDestination.
func (*EventDestination) DeepCopyInto ¶
func (in *EventDestination) DeepCopyInto(out *EventDestination)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*EventDestination) DeepCopyObject ¶
func (in *EventDestination) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*EventDestination) GetCondition ¶
func (mg *EventDestination) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this EventDestination.
func (*EventDestination) GetConnectionDetailsMapping ¶
func (tr *EventDestination) GetConnectionDetailsMapping() map[string]string
GetConnectionDetailsMapping for this EventDestination
func (*EventDestination) GetDeletionPolicy ¶
func (mg *EventDestination) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this EventDestination.
func (*EventDestination) GetID ¶
func (tr *EventDestination) GetID() string
GetID returns ID of underlying Terraform resource of this EventDestination
func (*EventDestination) GetInitParameters ¶
func (tr *EventDestination) GetInitParameters() (map[string]any, error)
GetInitParameters of this EventDestination
func (*EventDestination) GetManagementPolicies ¶
func (mg *EventDestination) GetManagementPolicies() xpv1.ManagementPolicies
GetManagementPolicies of this EventDestination.
func (*EventDestination) GetMergedParameters ¶
func (tr *EventDestination) GetMergedParameters(shouldMergeInitProvider bool) (map[string]any, error)
GetInitParameters of this EventDestination
func (*EventDestination) GetObservation ¶
func (tr *EventDestination) GetObservation() (map[string]any, error)
GetObservation of this EventDestination
func (*EventDestination) GetParameters ¶
func (tr *EventDestination) GetParameters() (map[string]any, error)
GetParameters of this EventDestination
func (*EventDestination) GetProviderConfigReference ¶
func (mg *EventDestination) GetProviderConfigReference() *xpv1.Reference
GetProviderConfigReference of this EventDestination.
func (*EventDestination) GetPublishConnectionDetailsTo ¶
func (mg *EventDestination) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this EventDestination.
func (*EventDestination) GetTerraformResourceType ¶
func (mg *EventDestination) GetTerraformResourceType() string
GetTerraformResourceType returns Terraform resource type for this EventDestination
func (*EventDestination) GetTerraformSchemaVersion ¶
func (tr *EventDestination) GetTerraformSchemaVersion() int
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*EventDestination) GetWriteConnectionSecretToReference ¶
func (mg *EventDestination) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this EventDestination.
func (*EventDestination) Hub ¶
func (tr *EventDestination) Hub()
Hub marks this type as a conversion hub.
func (*EventDestination) LateInitialize ¶
func (tr *EventDestination) LateInitialize(attrs []byte) (bool, error)
LateInitialize this EventDestination using its observed tfState. returns True if there are any spec changes for the resource.
func (*EventDestination) ResolveReferences ¶
func (*EventDestination) SetConditions ¶
func (mg *EventDestination) SetConditions(c ...xpv1.Condition)
SetConditions of this EventDestination.
func (*EventDestination) SetDeletionPolicy ¶
func (mg *EventDestination) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this EventDestination.
func (*EventDestination) SetManagementPolicies ¶
func (mg *EventDestination) SetManagementPolicies(r xpv1.ManagementPolicies)
SetManagementPolicies of this EventDestination.
func (*EventDestination) SetObservation ¶
func (tr *EventDestination) SetObservation(obs map[string]any) error
SetObservation for this EventDestination
func (*EventDestination) SetParameters ¶
func (tr *EventDestination) SetParameters(params map[string]any) error
SetParameters for this EventDestination
func (*EventDestination) SetProviderConfigReference ¶
func (mg *EventDestination) SetProviderConfigReference(r *xpv1.Reference)
SetProviderConfigReference of this EventDestination.
func (*EventDestination) SetPublishConnectionDetailsTo ¶
func (mg *EventDestination) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this EventDestination.
func (*EventDestination) SetWriteConnectionSecretToReference ¶
func (mg *EventDestination) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this EventDestination.
type EventDestinationInitParameters ¶
type EventDestinationInitParameters struct {
// CloudWatch destination for the events
CloudwatchDestination []CloudwatchDestinationInitParameters `json:"cloudwatchDestination,omitempty" tf:"cloudwatch_destination,omitempty"`
// The name of the configuration set
// +crossplane:generate:reference:type=github.com/upbound/provider-aws/apis/ses/v1beta2.ConfigurationSet
ConfigurationSetName *string `json:"configurationSetName,omitempty" tf:"configuration_set_name,omitempty"`
// Reference to a ConfigurationSet in ses to populate configurationSetName.
// +kubebuilder:validation:Optional
ConfigurationSetNameRef *v1.Reference `json:"configurationSetNameRef,omitempty" tf:"-"`
// Selector for a ConfigurationSet in ses to populate configurationSetName.
// +kubebuilder:validation:Optional
ConfigurationSetNameSelector *v1.Selector `json:"configurationSetNameSelector,omitempty" tf:"-"`
// If true, the event destination will be enabled
Enabled *bool `json:"enabled,omitempty" tf:"enabled,omitempty"`
// Send the events to a kinesis firehose destination
KinesisDestination *KinesisDestinationInitParameters `json:"kinesisDestination,omitempty" tf:"kinesis_destination,omitempty"`
// A list of matching types. May be any of "send", "reject", "bounce", "complaint", "delivery", "open", "click", or "renderingFailure".
// +listType=set
MatchingTypes []*string `json:"matchingTypes,omitempty" tf:"matching_types,omitempty"`
// Send the events to an SNS Topic destination
SnsDestination *SnsDestinationInitParameters `json:"snsDestination,omitempty" tf:"sns_destination,omitempty"`
}
func (*EventDestinationInitParameters) DeepCopy ¶
func (in *EventDestinationInitParameters) DeepCopy() *EventDestinationInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventDestinationInitParameters.
func (*EventDestinationInitParameters) DeepCopyInto ¶
func (in *EventDestinationInitParameters) DeepCopyInto(out *EventDestinationInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EventDestinationList ¶
type EventDestinationList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []EventDestination `json:"items"`
}
EventDestinationList contains a list of EventDestinations
func (*EventDestinationList) DeepCopy ¶
func (in *EventDestinationList) DeepCopy() *EventDestinationList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventDestinationList.
func (*EventDestinationList) DeepCopyInto ¶
func (in *EventDestinationList) DeepCopyInto(out *EventDestinationList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*EventDestinationList) DeepCopyObject ¶
func (in *EventDestinationList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*EventDestinationList) GetItems ¶
func (l *EventDestinationList) GetItems() []resource.Managed
GetItems of this EventDestinationList.
type EventDestinationObservation ¶
type EventDestinationObservation struct {
// The SES event destination ARN.
Arn *string `json:"arn,omitempty" tf:"arn,omitempty"`
// CloudWatch destination for the events
CloudwatchDestination []CloudwatchDestinationObservation `json:"cloudwatchDestination,omitempty" tf:"cloudwatch_destination,omitempty"`
// The name of the configuration set
ConfigurationSetName *string `json:"configurationSetName,omitempty" tf:"configuration_set_name,omitempty"`
// If true, the event destination will be enabled
Enabled *bool `json:"enabled,omitempty" tf:"enabled,omitempty"`
// The SES event destination name.
ID *string `json:"id,omitempty" tf:"id,omitempty"`
// Send the events to a kinesis firehose destination
KinesisDestination *KinesisDestinationObservation `json:"kinesisDestination,omitempty" tf:"kinesis_destination,omitempty"`
// A list of matching types. May be any of "send", "reject", "bounce", "complaint", "delivery", "open", "click", or "renderingFailure".
// +listType=set
MatchingTypes []*string `json:"matchingTypes,omitempty" tf:"matching_types,omitempty"`
// Send the events to an SNS Topic destination
SnsDestination *SnsDestinationObservation `json:"snsDestination,omitempty" tf:"sns_destination,omitempty"`
}
func (*EventDestinationObservation) DeepCopy ¶
func (in *EventDestinationObservation) DeepCopy() *EventDestinationObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventDestinationObservation.
func (*EventDestinationObservation) DeepCopyInto ¶
func (in *EventDestinationObservation) DeepCopyInto(out *EventDestinationObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EventDestinationParameters ¶
type EventDestinationParameters struct {
// CloudWatch destination for the events
// +kubebuilder:validation:Optional
CloudwatchDestination []CloudwatchDestinationParameters `json:"cloudwatchDestination,omitempty" tf:"cloudwatch_destination,omitempty"`
// The name of the configuration set
// +crossplane:generate:reference:type=github.com/upbound/provider-aws/apis/ses/v1beta2.ConfigurationSet
// +kubebuilder:validation:Optional
ConfigurationSetName *string `json:"configurationSetName,omitempty" tf:"configuration_set_name,omitempty"`
// Reference to a ConfigurationSet in ses to populate configurationSetName.
// +kubebuilder:validation:Optional
ConfigurationSetNameRef *v1.Reference `json:"configurationSetNameRef,omitempty" tf:"-"`
// Selector for a ConfigurationSet in ses to populate configurationSetName.
// +kubebuilder:validation:Optional
ConfigurationSetNameSelector *v1.Selector `json:"configurationSetNameSelector,omitempty" tf:"-"`
// If true, the event destination will be enabled
// +kubebuilder:validation:Optional
Enabled *bool `json:"enabled,omitempty" tf:"enabled,omitempty"`
// Send the events to a kinesis firehose destination
// +kubebuilder:validation:Optional
KinesisDestination *KinesisDestinationParameters `json:"kinesisDestination,omitempty" tf:"kinesis_destination,omitempty"`
// A list of matching types. May be any of "send", "reject", "bounce", "complaint", "delivery", "open", "click", or "renderingFailure".
// +kubebuilder:validation:Optional
// +listType=set
MatchingTypes []*string `json:"matchingTypes,omitempty" tf:"matching_types,omitempty"`
// Region is the region you'd like your resource to be created in.
// +upjet:crd:field:TFTag=-
// +kubebuilder:validation:Required
Region *string `json:"region" tf:"-"`
// Send the events to an SNS Topic destination
// +kubebuilder:validation:Optional
SnsDestination *SnsDestinationParameters `json:"snsDestination,omitempty" tf:"sns_destination,omitempty"`
}
func (*EventDestinationParameters) DeepCopy ¶
func (in *EventDestinationParameters) DeepCopy() *EventDestinationParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventDestinationParameters.
func (*EventDestinationParameters) DeepCopyInto ¶
func (in *EventDestinationParameters) DeepCopyInto(out *EventDestinationParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EventDestinationSpec ¶
type EventDestinationSpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider EventDestinationParameters `json:"forProvider"`
// THIS IS A BETA FIELD. It will be honored
// unless the Management Policies feature flag is disabled.
// InitProvider holds the same fields as ForProvider, with the exception
// of Identifier and other resource reference fields. The fields that are
// in InitProvider are merged into ForProvider when the resource is created.
// The same fields are also added to the terraform ignore_changes hook, to
// avoid updating them after creation. This is useful for fields that are
// required on creation, but we do not desire to update them after creation,
// for example because of an external controller is managing them, like an
// autoscaler.
InitProvider EventDestinationInitParameters `json:"initProvider,omitempty"`
}
EventDestinationSpec defines the desired state of EventDestination
func (*EventDestinationSpec) DeepCopy ¶
func (in *EventDestinationSpec) DeepCopy() *EventDestinationSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventDestinationSpec.
func (*EventDestinationSpec) DeepCopyInto ¶
func (in *EventDestinationSpec) DeepCopyInto(out *EventDestinationSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EventDestinationStatus ¶
type EventDestinationStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider EventDestinationObservation `json:"atProvider,omitempty"`
}
EventDestinationStatus defines the observed state of EventDestination.
func (*EventDestinationStatus) DeepCopy ¶
func (in *EventDestinationStatus) DeepCopy() *EventDestinationStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventDestinationStatus.
func (*EventDestinationStatus) DeepCopyInto ¶
func (in *EventDestinationStatus) DeepCopyInto(out *EventDestinationStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type KinesisDestinationInitParameters ¶
type KinesisDestinationInitParameters struct {
// The ARN of the role that has permissions to access the Kinesis Stream
// +crossplane:generate:reference:type=github.com/upbound/provider-aws/apis/iam/v1beta1.Role
// +crossplane:generate:reference:extractor=github.com/crossplane/upjet/pkg/resource.ExtractParamPath("arn",true)
RoleArn *string `json:"roleArn,omitempty" tf:"role_arn,omitempty"`
// Reference to a Role in iam to populate roleArn.
// +kubebuilder:validation:Optional
RoleArnRef *v1.Reference `json:"roleArnRef,omitempty" tf:"-"`
// Selector for a Role in iam to populate roleArn.
// +kubebuilder:validation:Optional
RoleArnSelector *v1.Selector `json:"roleArnSelector,omitempty" tf:"-"`
// The ARN of the Kinesis Stream
// +crossplane:generate:reference:type=github.com/upbound/provider-aws/apis/firehose/v1beta2.DeliveryStream
// +crossplane:generate:reference:extractor=github.com/crossplane/upjet/pkg/resource.ExtractParamPath("arn",false)
StreamArn *string `json:"streamArn,omitempty" tf:"stream_arn,omitempty"`
// Reference to a DeliveryStream in firehose to populate streamArn.
// +kubebuilder:validation:Optional
StreamArnRef *v1.Reference `json:"streamArnRef,omitempty" tf:"-"`
// Selector for a DeliveryStream in firehose to populate streamArn.
// +kubebuilder:validation:Optional
StreamArnSelector *v1.Selector `json:"streamArnSelector,omitempty" tf:"-"`
}
func (*KinesisDestinationInitParameters) DeepCopy ¶
func (in *KinesisDestinationInitParameters) DeepCopy() *KinesisDestinationInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new KinesisDestinationInitParameters.
func (*KinesisDestinationInitParameters) DeepCopyInto ¶
func (in *KinesisDestinationInitParameters) DeepCopyInto(out *KinesisDestinationInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type KinesisDestinationObservation ¶
type KinesisDestinationObservation struct {
// The ARN of the role that has permissions to access the Kinesis Stream
RoleArn *string `json:"roleArn,omitempty" tf:"role_arn,omitempty"`
// The ARN of the Kinesis Stream
StreamArn *string `json:"streamArn,omitempty" tf:"stream_arn,omitempty"`
}
func (*KinesisDestinationObservation) DeepCopy ¶
func (in *KinesisDestinationObservation) DeepCopy() *KinesisDestinationObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new KinesisDestinationObservation.
func (*KinesisDestinationObservation) DeepCopyInto ¶
func (in *KinesisDestinationObservation) DeepCopyInto(out *KinesisDestinationObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type KinesisDestinationParameters ¶
type KinesisDestinationParameters struct {
// The ARN of the role that has permissions to access the Kinesis Stream
// +crossplane:generate:reference:type=github.com/upbound/provider-aws/apis/iam/v1beta1.Role
// +crossplane:generate:reference:extractor=github.com/crossplane/upjet/pkg/resource.ExtractParamPath("arn",true)
// +kubebuilder:validation:Optional
RoleArn *string `json:"roleArn,omitempty" tf:"role_arn,omitempty"`
// Reference to a Role in iam to populate roleArn.
// +kubebuilder:validation:Optional
RoleArnRef *v1.Reference `json:"roleArnRef,omitempty" tf:"-"`
// Selector for a Role in iam to populate roleArn.
// +kubebuilder:validation:Optional
RoleArnSelector *v1.Selector `json:"roleArnSelector,omitempty" tf:"-"`
// The ARN of the Kinesis Stream
// +crossplane:generate:reference:type=github.com/upbound/provider-aws/apis/firehose/v1beta2.DeliveryStream
// +crossplane:generate:reference:extractor=github.com/crossplane/upjet/pkg/resource.ExtractParamPath("arn",false)
// +kubebuilder:validation:Optional
StreamArn *string `json:"streamArn,omitempty" tf:"stream_arn,omitempty"`
// Reference to a DeliveryStream in firehose to populate streamArn.
// +kubebuilder:validation:Optional
StreamArnRef *v1.Reference `json:"streamArnRef,omitempty" tf:"-"`
// Selector for a DeliveryStream in firehose to populate streamArn.
// +kubebuilder:validation:Optional
StreamArnSelector *v1.Selector `json:"streamArnSelector,omitempty" tf:"-"`
}
func (*KinesisDestinationParameters) DeepCopy ¶
func (in *KinesisDestinationParameters) DeepCopy() *KinesisDestinationParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new KinesisDestinationParameters.
func (*KinesisDestinationParameters) DeepCopyInto ¶
func (in *KinesisDestinationParameters) DeepCopyInto(out *KinesisDestinationParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SnsDestinationInitParameters ¶
type SnsDestinationInitParameters struct {
// The ARN of the SNS topic
// +crossplane:generate:reference:type=github.com/upbound/provider-aws/apis/sns/v1beta1.Topic
// +crossplane:generate:reference:extractor=github.com/crossplane/upjet/pkg/resource.ExtractParamPath("arn",true)
TopicArn *string `json:"topicArn,omitempty" tf:"topic_arn,omitempty"`
// Reference to a Topic in sns to populate topicArn.
// +kubebuilder:validation:Optional
TopicArnRef *v1.Reference `json:"topicArnRef,omitempty" tf:"-"`
// Selector for a Topic in sns to populate topicArn.
// +kubebuilder:validation:Optional
TopicArnSelector *v1.Selector `json:"topicArnSelector,omitempty" tf:"-"`
}
func (*SnsDestinationInitParameters) DeepCopy ¶
func (in *SnsDestinationInitParameters) DeepCopy() *SnsDestinationInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SnsDestinationInitParameters.
func (*SnsDestinationInitParameters) DeepCopyInto ¶
func (in *SnsDestinationInitParameters) DeepCopyInto(out *SnsDestinationInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SnsDestinationObservation ¶
type SnsDestinationObservation struct {
// The ARN of the SNS topic
TopicArn *string `json:"topicArn,omitempty" tf:"topic_arn,omitempty"`
}
func (*SnsDestinationObservation) DeepCopy ¶
func (in *SnsDestinationObservation) DeepCopy() *SnsDestinationObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SnsDestinationObservation.
func (*SnsDestinationObservation) DeepCopyInto ¶
func (in *SnsDestinationObservation) DeepCopyInto(out *SnsDestinationObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SnsDestinationParameters ¶
type SnsDestinationParameters struct {
// The ARN of the SNS topic
// +crossplane:generate:reference:type=github.com/upbound/provider-aws/apis/sns/v1beta1.Topic
// +crossplane:generate:reference:extractor=github.com/crossplane/upjet/pkg/resource.ExtractParamPath("arn",true)
// +kubebuilder:validation:Optional
TopicArn *string `json:"topicArn,omitempty" tf:"topic_arn,omitempty"`
// Reference to a Topic in sns to populate topicArn.
// +kubebuilder:validation:Optional
TopicArnRef *v1.Reference `json:"topicArnRef,omitempty" tf:"-"`
// Selector for a Topic in sns to populate topicArn.
// +kubebuilder:validation:Optional
TopicArnSelector *v1.Selector `json:"topicArnSelector,omitempty" tf:"-"`
}
func (*SnsDestinationParameters) DeepCopy ¶
func (in *SnsDestinationParameters) DeepCopy() *SnsDestinationParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SnsDestinationParameters.
func (*SnsDestinationParameters) DeepCopyInto ¶
func (in *SnsDestinationParameters) DeepCopyInto(out *SnsDestinationParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TrackingOptionsInitParameters ¶
type TrackingOptionsInitParameters struct {
// Custom subdomain that is used to redirect email recipients to the Amazon SES event tracking domain.
CustomRedirectDomain *string `json:"customRedirectDomain,omitempty" tf:"custom_redirect_domain,omitempty"`
}
func (*TrackingOptionsInitParameters) DeepCopy ¶
func (in *TrackingOptionsInitParameters) DeepCopy() *TrackingOptionsInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TrackingOptionsInitParameters.
func (*TrackingOptionsInitParameters) DeepCopyInto ¶
func (in *TrackingOptionsInitParameters) DeepCopyInto(out *TrackingOptionsInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TrackingOptionsObservation ¶
type TrackingOptionsObservation struct {
// Custom subdomain that is used to redirect email recipients to the Amazon SES event tracking domain.
CustomRedirectDomain *string `json:"customRedirectDomain,omitempty" tf:"custom_redirect_domain,omitempty"`
}
func (*TrackingOptionsObservation) DeepCopy ¶
func (in *TrackingOptionsObservation) DeepCopy() *TrackingOptionsObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TrackingOptionsObservation.
func (*TrackingOptionsObservation) DeepCopyInto ¶
func (in *TrackingOptionsObservation) DeepCopyInto(out *TrackingOptionsObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TrackingOptionsParameters ¶
type TrackingOptionsParameters struct {
// Custom subdomain that is used to redirect email recipients to the Amazon SES event tracking domain.
// +kubebuilder:validation:Optional
CustomRedirectDomain *string `json:"customRedirectDomain,omitempty" tf:"custom_redirect_domain,omitempty"`
}
func (*TrackingOptionsParameters) DeepCopy ¶
func (in *TrackingOptionsParameters) DeepCopy() *TrackingOptionsParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TrackingOptionsParameters.
func (*TrackingOptionsParameters) DeepCopyInto ¶
func (in *TrackingOptionsParameters) DeepCopyInto(out *TrackingOptionsParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.