Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +groupName=ssoadmin.aws.upbound.io +versionName=v1beta2
Index ¶
- Constants
- Variables
- type CustomerManagedPolicyAttachment
- func (in *CustomerManagedPolicyAttachment) DeepCopy() *CustomerManagedPolicyAttachment
- func (in *CustomerManagedPolicyAttachment) DeepCopyInto(out *CustomerManagedPolicyAttachment)
- func (in *CustomerManagedPolicyAttachment) DeepCopyObject() runtime.Object
- func (mg *CustomerManagedPolicyAttachment) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *CustomerManagedPolicyAttachment) GetConnectionDetailsMapping() map[string]string
- func (mg *CustomerManagedPolicyAttachment) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *CustomerManagedPolicyAttachment) GetID() string
- func (tr *CustomerManagedPolicyAttachment) GetInitParameters() (map[string]any, error)
- func (mg *CustomerManagedPolicyAttachment) GetManagementPolicies() xpv1.ManagementPolicies
- func (tr *CustomerManagedPolicyAttachment) GetMergedParameters(shouldMergeInitProvider bool) (map[string]any, error)
- func (tr *CustomerManagedPolicyAttachment) GetObservation() (map[string]any, error)
- func (tr *CustomerManagedPolicyAttachment) GetParameters() (map[string]any, error)
- func (mg *CustomerManagedPolicyAttachment) GetProviderConfigReference() *xpv1.Reference
- func (mg *CustomerManagedPolicyAttachment) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *CustomerManagedPolicyAttachment) GetTerraformResourceType() string
- func (tr *CustomerManagedPolicyAttachment) GetTerraformSchemaVersion() int
- func (mg *CustomerManagedPolicyAttachment) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *CustomerManagedPolicyAttachment) Hub()
- func (tr *CustomerManagedPolicyAttachment) LateInitialize(attrs []byte) (bool, error)
- func (mg *CustomerManagedPolicyAttachment) ResolveReferences(ctx context.Context, c client.Reader) error
- func (mg *CustomerManagedPolicyAttachment) SetConditions(c ...xpv1.Condition)
- func (mg *CustomerManagedPolicyAttachment) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (mg *CustomerManagedPolicyAttachment) SetManagementPolicies(r xpv1.ManagementPolicies)
- func (tr *CustomerManagedPolicyAttachment) SetObservation(obs map[string]any) error
- func (tr *CustomerManagedPolicyAttachment) SetParameters(params map[string]any) error
- func (mg *CustomerManagedPolicyAttachment) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *CustomerManagedPolicyAttachment) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *CustomerManagedPolicyAttachment) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type CustomerManagedPolicyAttachmentInitParameters
- type CustomerManagedPolicyAttachmentList
- func (in *CustomerManagedPolicyAttachmentList) DeepCopy() *CustomerManagedPolicyAttachmentList
- func (in *CustomerManagedPolicyAttachmentList) DeepCopyInto(out *CustomerManagedPolicyAttachmentList)
- func (in *CustomerManagedPolicyAttachmentList) DeepCopyObject() runtime.Object
- func (l *CustomerManagedPolicyAttachmentList) GetItems() []resource.Managed
- type CustomerManagedPolicyAttachmentObservation
- type CustomerManagedPolicyAttachmentParameters
- type CustomerManagedPolicyAttachmentSpec
- type CustomerManagedPolicyAttachmentStatus
- type CustomerManagedPolicyReferenceInitParameters
- type CustomerManagedPolicyReferenceObservation
- type CustomerManagedPolicyReferenceParameters
- type PermissionsBoundaryAttachment
- func (in *PermissionsBoundaryAttachment) DeepCopy() *PermissionsBoundaryAttachment
- func (in *PermissionsBoundaryAttachment) DeepCopyInto(out *PermissionsBoundaryAttachment)
- func (in *PermissionsBoundaryAttachment) DeepCopyObject() runtime.Object
- func (mg *PermissionsBoundaryAttachment) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *PermissionsBoundaryAttachment) GetConnectionDetailsMapping() map[string]string
- func (mg *PermissionsBoundaryAttachment) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *PermissionsBoundaryAttachment) GetID() string
- func (tr *PermissionsBoundaryAttachment) GetInitParameters() (map[string]any, error)
- func (mg *PermissionsBoundaryAttachment) GetManagementPolicies() xpv1.ManagementPolicies
- func (tr *PermissionsBoundaryAttachment) GetMergedParameters(shouldMergeInitProvider bool) (map[string]any, error)
- func (tr *PermissionsBoundaryAttachment) GetObservation() (map[string]any, error)
- func (tr *PermissionsBoundaryAttachment) GetParameters() (map[string]any, error)
- func (mg *PermissionsBoundaryAttachment) GetProviderConfigReference() *xpv1.Reference
- func (mg *PermissionsBoundaryAttachment) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *PermissionsBoundaryAttachment) GetTerraformResourceType() string
- func (tr *PermissionsBoundaryAttachment) GetTerraformSchemaVersion() int
- func (mg *PermissionsBoundaryAttachment) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *PermissionsBoundaryAttachment) Hub()
- func (tr *PermissionsBoundaryAttachment) LateInitialize(attrs []byte) (bool, error)
- func (mg *PermissionsBoundaryAttachment) ResolveReferences(ctx context.Context, c client.Reader) error
- func (mg *PermissionsBoundaryAttachment) SetConditions(c ...xpv1.Condition)
- func (mg *PermissionsBoundaryAttachment) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (mg *PermissionsBoundaryAttachment) SetManagementPolicies(r xpv1.ManagementPolicies)
- func (tr *PermissionsBoundaryAttachment) SetObservation(obs map[string]any) error
- func (tr *PermissionsBoundaryAttachment) SetParameters(params map[string]any) error
- func (mg *PermissionsBoundaryAttachment) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *PermissionsBoundaryAttachment) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *PermissionsBoundaryAttachment) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type PermissionsBoundaryAttachmentInitParameters
- type PermissionsBoundaryAttachmentList
- func (in *PermissionsBoundaryAttachmentList) DeepCopy() *PermissionsBoundaryAttachmentList
- func (in *PermissionsBoundaryAttachmentList) DeepCopyInto(out *PermissionsBoundaryAttachmentList)
- func (in *PermissionsBoundaryAttachmentList) DeepCopyObject() runtime.Object
- func (l *PermissionsBoundaryAttachmentList) GetItems() []resource.Managed
- type PermissionsBoundaryAttachmentObservation
- type PermissionsBoundaryAttachmentParameters
- type PermissionsBoundaryAttachmentSpec
- type PermissionsBoundaryAttachmentStatus
- type PermissionsBoundaryCustomerManagedPolicyReferenceInitParameters
- func (in *PermissionsBoundaryCustomerManagedPolicyReferenceInitParameters) DeepCopy() *PermissionsBoundaryCustomerManagedPolicyReferenceInitParameters
- func (in *PermissionsBoundaryCustomerManagedPolicyReferenceInitParameters) DeepCopyInto(out *PermissionsBoundaryCustomerManagedPolicyReferenceInitParameters)
- type PermissionsBoundaryCustomerManagedPolicyReferenceObservation
- type PermissionsBoundaryCustomerManagedPolicyReferenceParameters
- type PermissionsBoundaryInitParameters
- type PermissionsBoundaryObservation
- type PermissionsBoundaryParameters
Constants ¶
const ( CRDGroup = "ssoadmin.aws.upbound.io" CRDVersion = "v1beta2" )
Package type metadata.
Variables ¶
var ( CustomerManagedPolicyAttachment_Kind = "CustomerManagedPolicyAttachment" CustomerManagedPolicyAttachment_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: CustomerManagedPolicyAttachment_Kind}.String() CustomerManagedPolicyAttachment_KindAPIVersion = CustomerManagedPolicyAttachment_Kind + "." + CRDGroupVersion.String() CustomerManagedPolicyAttachment_GroupVersionKind = CRDGroupVersion.WithKind(CustomerManagedPolicyAttachment_Kind) )
Repository type metadata.
var ( // CRDGroupVersion is the API Group Version used to register the objects CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
var ( PermissionsBoundaryAttachment_Kind = "PermissionsBoundaryAttachment" PermissionsBoundaryAttachment_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: PermissionsBoundaryAttachment_Kind}.String() PermissionsBoundaryAttachment_KindAPIVersion = PermissionsBoundaryAttachment_Kind + "." + CRDGroupVersion.String() PermissionsBoundaryAttachment_GroupVersionKind = CRDGroupVersion.WithKind(PermissionsBoundaryAttachment_Kind) )
Repository type metadata.
Functions ¶
This section is empty.
Types ¶
type CustomerManagedPolicyAttachment ¶
type CustomerManagedPolicyAttachment struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.customerManagedPolicyReference) || (has(self.initProvider) && has(self.initProvider.customerManagedPolicyReference))",message="spec.forProvider.customerManagedPolicyReference is a required parameter"
Spec CustomerManagedPolicyAttachmentSpec `json:"spec"`
Status CustomerManagedPolicyAttachmentStatus `json:"status,omitempty"`
}
CustomerManagedPolicyAttachment is the Schema for the CustomerManagedPolicyAttachments API. Manages a customer managed policy for a Single Sign-On (SSO) Permission Set +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,aws}
func (*CustomerManagedPolicyAttachment) DeepCopy ¶
func (in *CustomerManagedPolicyAttachment) DeepCopy() *CustomerManagedPolicyAttachment
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CustomerManagedPolicyAttachment.
func (*CustomerManagedPolicyAttachment) DeepCopyInto ¶
func (in *CustomerManagedPolicyAttachment) DeepCopyInto(out *CustomerManagedPolicyAttachment)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CustomerManagedPolicyAttachment) DeepCopyObject ¶
func (in *CustomerManagedPolicyAttachment) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*CustomerManagedPolicyAttachment) GetCondition ¶
func (mg *CustomerManagedPolicyAttachment) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this CustomerManagedPolicyAttachment.
func (*CustomerManagedPolicyAttachment) GetConnectionDetailsMapping ¶
func (tr *CustomerManagedPolicyAttachment) GetConnectionDetailsMapping() map[string]string
GetConnectionDetailsMapping for this CustomerManagedPolicyAttachment
func (*CustomerManagedPolicyAttachment) GetDeletionPolicy ¶
func (mg *CustomerManagedPolicyAttachment) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this CustomerManagedPolicyAttachment.
func (*CustomerManagedPolicyAttachment) GetID ¶
func (tr *CustomerManagedPolicyAttachment) GetID() string
GetID returns ID of underlying Terraform resource of this CustomerManagedPolicyAttachment
func (*CustomerManagedPolicyAttachment) GetInitParameters ¶
func (tr *CustomerManagedPolicyAttachment) GetInitParameters() (map[string]any, error)
GetInitParameters of this CustomerManagedPolicyAttachment
func (*CustomerManagedPolicyAttachment) GetManagementPolicies ¶
func (mg *CustomerManagedPolicyAttachment) GetManagementPolicies() xpv1.ManagementPolicies
GetManagementPolicies of this CustomerManagedPolicyAttachment.
func (*CustomerManagedPolicyAttachment) GetMergedParameters ¶
func (tr *CustomerManagedPolicyAttachment) GetMergedParameters(shouldMergeInitProvider bool) (map[string]any, error)
GetInitParameters of this CustomerManagedPolicyAttachment
func (*CustomerManagedPolicyAttachment) GetObservation ¶
func (tr *CustomerManagedPolicyAttachment) GetObservation() (map[string]any, error)
GetObservation of this CustomerManagedPolicyAttachment
func (*CustomerManagedPolicyAttachment) GetParameters ¶
func (tr *CustomerManagedPolicyAttachment) GetParameters() (map[string]any, error)
GetParameters of this CustomerManagedPolicyAttachment
func (*CustomerManagedPolicyAttachment) GetProviderConfigReference ¶
func (mg *CustomerManagedPolicyAttachment) GetProviderConfigReference() *xpv1.Reference
GetProviderConfigReference of this CustomerManagedPolicyAttachment.
func (*CustomerManagedPolicyAttachment) GetPublishConnectionDetailsTo ¶
func (mg *CustomerManagedPolicyAttachment) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this CustomerManagedPolicyAttachment.
func (*CustomerManagedPolicyAttachment) GetTerraformResourceType ¶
func (mg *CustomerManagedPolicyAttachment) GetTerraformResourceType() string
GetTerraformResourceType returns Terraform resource type for this CustomerManagedPolicyAttachment
func (*CustomerManagedPolicyAttachment) GetTerraformSchemaVersion ¶
func (tr *CustomerManagedPolicyAttachment) GetTerraformSchemaVersion() int
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*CustomerManagedPolicyAttachment) GetWriteConnectionSecretToReference ¶
func (mg *CustomerManagedPolicyAttachment) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this CustomerManagedPolicyAttachment.
func (*CustomerManagedPolicyAttachment) Hub ¶
func (tr *CustomerManagedPolicyAttachment) Hub()
Hub marks this type as a conversion hub.
func (*CustomerManagedPolicyAttachment) LateInitialize ¶
func (tr *CustomerManagedPolicyAttachment) LateInitialize(attrs []byte) (bool, error)
LateInitialize this CustomerManagedPolicyAttachment using its observed tfState. returns True if there are any spec changes for the resource.
func (*CustomerManagedPolicyAttachment) ResolveReferences ¶
func (*CustomerManagedPolicyAttachment) SetConditions ¶
func (mg *CustomerManagedPolicyAttachment) SetConditions(c ...xpv1.Condition)
SetConditions of this CustomerManagedPolicyAttachment.
func (*CustomerManagedPolicyAttachment) SetDeletionPolicy ¶
func (mg *CustomerManagedPolicyAttachment) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this CustomerManagedPolicyAttachment.
func (*CustomerManagedPolicyAttachment) SetManagementPolicies ¶
func (mg *CustomerManagedPolicyAttachment) SetManagementPolicies(r xpv1.ManagementPolicies)
SetManagementPolicies of this CustomerManagedPolicyAttachment.
func (*CustomerManagedPolicyAttachment) SetObservation ¶
func (tr *CustomerManagedPolicyAttachment) SetObservation(obs map[string]any) error
SetObservation for this CustomerManagedPolicyAttachment
func (*CustomerManagedPolicyAttachment) SetParameters ¶
func (tr *CustomerManagedPolicyAttachment) SetParameters(params map[string]any) error
SetParameters for this CustomerManagedPolicyAttachment
func (*CustomerManagedPolicyAttachment) SetProviderConfigReference ¶
func (mg *CustomerManagedPolicyAttachment) SetProviderConfigReference(r *xpv1.Reference)
SetProviderConfigReference of this CustomerManagedPolicyAttachment.
func (*CustomerManagedPolicyAttachment) SetPublishConnectionDetailsTo ¶
func (mg *CustomerManagedPolicyAttachment) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this CustomerManagedPolicyAttachment.
func (*CustomerManagedPolicyAttachment) SetWriteConnectionSecretToReference ¶
func (mg *CustomerManagedPolicyAttachment) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this CustomerManagedPolicyAttachment.
type CustomerManagedPolicyAttachmentInitParameters ¶
type CustomerManagedPolicyAttachmentInitParameters struct {
// Specifies the name and path of a customer managed policy. See below.
CustomerManagedPolicyReference *CustomerManagedPolicyReferenceInitParameters `json:"customerManagedPolicyReference,omitempty" tf:"customer_managed_policy_reference,omitempty"`
}
func (*CustomerManagedPolicyAttachmentInitParameters) DeepCopy ¶
func (in *CustomerManagedPolicyAttachmentInitParameters) DeepCopy() *CustomerManagedPolicyAttachmentInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CustomerManagedPolicyAttachmentInitParameters.
func (*CustomerManagedPolicyAttachmentInitParameters) DeepCopyInto ¶
func (in *CustomerManagedPolicyAttachmentInitParameters) DeepCopyInto(out *CustomerManagedPolicyAttachmentInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CustomerManagedPolicyAttachmentList ¶
type CustomerManagedPolicyAttachmentList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []CustomerManagedPolicyAttachment `json:"items"`
}
CustomerManagedPolicyAttachmentList contains a list of CustomerManagedPolicyAttachments
func (*CustomerManagedPolicyAttachmentList) DeepCopy ¶
func (in *CustomerManagedPolicyAttachmentList) DeepCopy() *CustomerManagedPolicyAttachmentList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CustomerManagedPolicyAttachmentList.
func (*CustomerManagedPolicyAttachmentList) DeepCopyInto ¶
func (in *CustomerManagedPolicyAttachmentList) DeepCopyInto(out *CustomerManagedPolicyAttachmentList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CustomerManagedPolicyAttachmentList) DeepCopyObject ¶
func (in *CustomerManagedPolicyAttachmentList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*CustomerManagedPolicyAttachmentList) GetItems ¶
func (l *CustomerManagedPolicyAttachmentList) GetItems() []resource.Managed
GetItems of this CustomerManagedPolicyAttachmentList.
type CustomerManagedPolicyAttachmentObservation ¶
type CustomerManagedPolicyAttachmentObservation struct {
// Specifies the name and path of a customer managed policy. See below.
CustomerManagedPolicyReference *CustomerManagedPolicyReferenceObservation `json:"customerManagedPolicyReference,omitempty" tf:"customer_managed_policy_reference,omitempty"`
// Policy Name, Policy Path, Permission Set Amazon Resource Name (ARN), and SSO Instance ARN, each separated by a comma (,).
ID *string `json:"id,omitempty" tf:"id,omitempty"`
// The Amazon Resource Name (ARN) of the SSO Instance under which the operation will be executed.
InstanceArn *string `json:"instanceArn,omitempty" tf:"instance_arn,omitempty"`
// The Amazon Resource Name (ARN) of the Permission Set.
PermissionSetArn *string `json:"permissionSetArn,omitempty" tf:"permission_set_arn,omitempty"`
}
func (*CustomerManagedPolicyAttachmentObservation) DeepCopy ¶
func (in *CustomerManagedPolicyAttachmentObservation) DeepCopy() *CustomerManagedPolicyAttachmentObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CustomerManagedPolicyAttachmentObservation.
func (*CustomerManagedPolicyAttachmentObservation) DeepCopyInto ¶
func (in *CustomerManagedPolicyAttachmentObservation) DeepCopyInto(out *CustomerManagedPolicyAttachmentObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CustomerManagedPolicyAttachmentParameters ¶
type CustomerManagedPolicyAttachmentParameters struct {
// Specifies the name and path of a customer managed policy. See below.
// +kubebuilder:validation:Optional
CustomerManagedPolicyReference *CustomerManagedPolicyReferenceParameters `json:"customerManagedPolicyReference,omitempty" tf:"customer_managed_policy_reference,omitempty"`
// The Amazon Resource Name (ARN) of the SSO Instance under which the operation will be executed.
// +kubebuilder:validation:Required
InstanceArn *string `json:"instanceArn" tf:"instance_arn,omitempty"`
// The Amazon Resource Name (ARN) of the Permission Set.
// +crossplane:generate:reference:type=github.com/upbound/provider-aws/apis/ssoadmin/v1beta1.PermissionSet
// +crossplane:generate:reference:extractor=github.com/crossplane/upjet/pkg/resource.ExtractParamPath("arn",true)
// +kubebuilder:validation:Optional
PermissionSetArn *string `json:"permissionSetArn,omitempty" tf:"permission_set_arn,omitempty"`
// Reference to a PermissionSet in ssoadmin to populate permissionSetArn.
// +kubebuilder:validation:Optional
PermissionSetArnRef *v1.Reference `json:"permissionSetArnRef,omitempty" tf:"-"`
// Selector for a PermissionSet in ssoadmin to populate permissionSetArn.
// +kubebuilder:validation:Optional
PermissionSetArnSelector *v1.Selector `json:"permissionSetArnSelector,omitempty" tf:"-"`
// Region is the region you'd like your resource to be created in.
// +upjet:crd:field:TFTag=-
// +kubebuilder:validation:Required
Region *string `json:"region" tf:"-"`
}
func (*CustomerManagedPolicyAttachmentParameters) DeepCopy ¶
func (in *CustomerManagedPolicyAttachmentParameters) DeepCopy() *CustomerManagedPolicyAttachmentParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CustomerManagedPolicyAttachmentParameters.
func (*CustomerManagedPolicyAttachmentParameters) DeepCopyInto ¶
func (in *CustomerManagedPolicyAttachmentParameters) DeepCopyInto(out *CustomerManagedPolicyAttachmentParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CustomerManagedPolicyAttachmentSpec ¶
type CustomerManagedPolicyAttachmentSpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider CustomerManagedPolicyAttachmentParameters `json:"forProvider"`
// THIS IS A BETA FIELD. It will be honored
// unless the Management Policies feature flag is disabled.
// InitProvider holds the same fields as ForProvider, with the exception
// of Identifier and other resource reference fields. The fields that are
// in InitProvider are merged into ForProvider when the resource is created.
// The same fields are also added to the terraform ignore_changes hook, to
// avoid updating them after creation. This is useful for fields that are
// required on creation, but we do not desire to update them after creation,
// for example because of an external controller is managing them, like an
// autoscaler.
InitProvider CustomerManagedPolicyAttachmentInitParameters `json:"initProvider,omitempty"`
}
CustomerManagedPolicyAttachmentSpec defines the desired state of CustomerManagedPolicyAttachment
func (*CustomerManagedPolicyAttachmentSpec) DeepCopy ¶
func (in *CustomerManagedPolicyAttachmentSpec) DeepCopy() *CustomerManagedPolicyAttachmentSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CustomerManagedPolicyAttachmentSpec.
func (*CustomerManagedPolicyAttachmentSpec) DeepCopyInto ¶
func (in *CustomerManagedPolicyAttachmentSpec) DeepCopyInto(out *CustomerManagedPolicyAttachmentSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CustomerManagedPolicyAttachmentStatus ¶
type CustomerManagedPolicyAttachmentStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider CustomerManagedPolicyAttachmentObservation `json:"atProvider,omitempty"`
}
CustomerManagedPolicyAttachmentStatus defines the observed state of CustomerManagedPolicyAttachment.
func (*CustomerManagedPolicyAttachmentStatus) DeepCopy ¶
func (in *CustomerManagedPolicyAttachmentStatus) DeepCopy() *CustomerManagedPolicyAttachmentStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CustomerManagedPolicyAttachmentStatus.
func (*CustomerManagedPolicyAttachmentStatus) DeepCopyInto ¶
func (in *CustomerManagedPolicyAttachmentStatus) DeepCopyInto(out *CustomerManagedPolicyAttachmentStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CustomerManagedPolicyReferenceInitParameters ¶
type CustomerManagedPolicyReferenceInitParameters struct {
// Name of the customer managed IAM Policy to be attached.
// +crossplane:generate:reference:type=github.com/upbound/provider-aws/apis/iam/v1beta1.Policy
// +crossplane:generate:reference:refFieldName=PolicyNameRef
// +crossplane:generate:reference:selectorFieldName=PolicyNameSelector
Name *string `json:"name,omitempty" tf:"name,omitempty"`
// The path to the IAM policy to be attached. The default is /. See IAM Identifiers for more information.
Path *string `json:"path,omitempty" tf:"path,omitempty"`
// Reference to a Policy in iam to populate name.
// +kubebuilder:validation:Optional
PolicyNameRef *v1.Reference `json:"policyNameRef,omitempty" tf:"-"`
// Selector for a Policy in iam to populate name.
// +kubebuilder:validation:Optional
PolicyNameSelector *v1.Selector `json:"policyNameSelector,omitempty" tf:"-"`
}
func (*CustomerManagedPolicyReferenceInitParameters) DeepCopy ¶
func (in *CustomerManagedPolicyReferenceInitParameters) DeepCopy() *CustomerManagedPolicyReferenceInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CustomerManagedPolicyReferenceInitParameters.
func (*CustomerManagedPolicyReferenceInitParameters) DeepCopyInto ¶
func (in *CustomerManagedPolicyReferenceInitParameters) DeepCopyInto(out *CustomerManagedPolicyReferenceInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CustomerManagedPolicyReferenceObservation ¶
type CustomerManagedPolicyReferenceObservation struct {
// Name of the customer managed IAM Policy to be attached.
Name *string `json:"name,omitempty" tf:"name,omitempty"`
// The path to the IAM policy to be attached. The default is /. See IAM Identifiers for more information.
Path *string `json:"path,omitempty" tf:"path,omitempty"`
}
func (*CustomerManagedPolicyReferenceObservation) DeepCopy ¶
func (in *CustomerManagedPolicyReferenceObservation) DeepCopy() *CustomerManagedPolicyReferenceObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CustomerManagedPolicyReferenceObservation.
func (*CustomerManagedPolicyReferenceObservation) DeepCopyInto ¶
func (in *CustomerManagedPolicyReferenceObservation) DeepCopyInto(out *CustomerManagedPolicyReferenceObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CustomerManagedPolicyReferenceParameters ¶
type CustomerManagedPolicyReferenceParameters struct {
// Name of the customer managed IAM Policy to be attached.
// +crossplane:generate:reference:type=github.com/upbound/provider-aws/apis/iam/v1beta1.Policy
// +crossplane:generate:reference:refFieldName=PolicyNameRef
// +crossplane:generate:reference:selectorFieldName=PolicyNameSelector
// +kubebuilder:validation:Optional
Name *string `json:"name,omitempty" tf:"name,omitempty"`
// The path to the IAM policy to be attached. The default is /. See IAM Identifiers for more information.
// +kubebuilder:validation:Optional
Path *string `json:"path,omitempty" tf:"path,omitempty"`
// Reference to a Policy in iam to populate name.
// +kubebuilder:validation:Optional
PolicyNameRef *v1.Reference `json:"policyNameRef,omitempty" tf:"-"`
// Selector for a Policy in iam to populate name.
// +kubebuilder:validation:Optional
PolicyNameSelector *v1.Selector `json:"policyNameSelector,omitempty" tf:"-"`
}
func (*CustomerManagedPolicyReferenceParameters) DeepCopy ¶
func (in *CustomerManagedPolicyReferenceParameters) DeepCopy() *CustomerManagedPolicyReferenceParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CustomerManagedPolicyReferenceParameters.
func (*CustomerManagedPolicyReferenceParameters) DeepCopyInto ¶
func (in *CustomerManagedPolicyReferenceParameters) DeepCopyInto(out *CustomerManagedPolicyReferenceParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PermissionsBoundaryAttachment ¶
type PermissionsBoundaryAttachment struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.permissionsBoundary) || (has(self.initProvider) && has(self.initProvider.permissionsBoundary))",message="spec.forProvider.permissionsBoundary is a required parameter"
Spec PermissionsBoundaryAttachmentSpec `json:"spec"`
Status PermissionsBoundaryAttachmentStatus `json:"status,omitempty"`
}
PermissionsBoundaryAttachment is the Schema for the PermissionsBoundaryAttachments API. Attaches a permissions boundary policy to a Single Sign-On (SSO) Permission Set resource. +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,aws}
func (*PermissionsBoundaryAttachment) DeepCopy ¶
func (in *PermissionsBoundaryAttachment) DeepCopy() *PermissionsBoundaryAttachment
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PermissionsBoundaryAttachment.
func (*PermissionsBoundaryAttachment) DeepCopyInto ¶
func (in *PermissionsBoundaryAttachment) DeepCopyInto(out *PermissionsBoundaryAttachment)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*PermissionsBoundaryAttachment) DeepCopyObject ¶
func (in *PermissionsBoundaryAttachment) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*PermissionsBoundaryAttachment) GetCondition ¶
func (mg *PermissionsBoundaryAttachment) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this PermissionsBoundaryAttachment.
func (*PermissionsBoundaryAttachment) GetConnectionDetailsMapping ¶
func (tr *PermissionsBoundaryAttachment) GetConnectionDetailsMapping() map[string]string
GetConnectionDetailsMapping for this PermissionsBoundaryAttachment
func (*PermissionsBoundaryAttachment) GetDeletionPolicy ¶
func (mg *PermissionsBoundaryAttachment) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this PermissionsBoundaryAttachment.
func (*PermissionsBoundaryAttachment) GetID ¶
func (tr *PermissionsBoundaryAttachment) GetID() string
GetID returns ID of underlying Terraform resource of this PermissionsBoundaryAttachment
func (*PermissionsBoundaryAttachment) GetInitParameters ¶
func (tr *PermissionsBoundaryAttachment) GetInitParameters() (map[string]any, error)
GetInitParameters of this PermissionsBoundaryAttachment
func (*PermissionsBoundaryAttachment) GetManagementPolicies ¶
func (mg *PermissionsBoundaryAttachment) GetManagementPolicies() xpv1.ManagementPolicies
GetManagementPolicies of this PermissionsBoundaryAttachment.
func (*PermissionsBoundaryAttachment) GetMergedParameters ¶
func (tr *PermissionsBoundaryAttachment) GetMergedParameters(shouldMergeInitProvider bool) (map[string]any, error)
GetInitParameters of this PermissionsBoundaryAttachment
func (*PermissionsBoundaryAttachment) GetObservation ¶
func (tr *PermissionsBoundaryAttachment) GetObservation() (map[string]any, error)
GetObservation of this PermissionsBoundaryAttachment
func (*PermissionsBoundaryAttachment) GetParameters ¶
func (tr *PermissionsBoundaryAttachment) GetParameters() (map[string]any, error)
GetParameters of this PermissionsBoundaryAttachment
func (*PermissionsBoundaryAttachment) GetProviderConfigReference ¶
func (mg *PermissionsBoundaryAttachment) GetProviderConfigReference() *xpv1.Reference
GetProviderConfigReference of this PermissionsBoundaryAttachment.
func (*PermissionsBoundaryAttachment) GetPublishConnectionDetailsTo ¶
func (mg *PermissionsBoundaryAttachment) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this PermissionsBoundaryAttachment.
func (*PermissionsBoundaryAttachment) GetTerraformResourceType ¶
func (mg *PermissionsBoundaryAttachment) GetTerraformResourceType() string
GetTerraformResourceType returns Terraform resource type for this PermissionsBoundaryAttachment
func (*PermissionsBoundaryAttachment) GetTerraformSchemaVersion ¶
func (tr *PermissionsBoundaryAttachment) GetTerraformSchemaVersion() int
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*PermissionsBoundaryAttachment) GetWriteConnectionSecretToReference ¶
func (mg *PermissionsBoundaryAttachment) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this PermissionsBoundaryAttachment.
func (*PermissionsBoundaryAttachment) Hub ¶
func (tr *PermissionsBoundaryAttachment) Hub()
Hub marks this type as a conversion hub.
func (*PermissionsBoundaryAttachment) LateInitialize ¶
func (tr *PermissionsBoundaryAttachment) LateInitialize(attrs []byte) (bool, error)
LateInitialize this PermissionsBoundaryAttachment using its observed tfState. returns True if there are any spec changes for the resource.
func (*PermissionsBoundaryAttachment) ResolveReferences ¶
func (mg *PermissionsBoundaryAttachment) ResolveReferences(ctx context.Context, c client.Reader) error
ResolveReferences of this PermissionsBoundaryAttachment.
func (*PermissionsBoundaryAttachment) SetConditions ¶
func (mg *PermissionsBoundaryAttachment) SetConditions(c ...xpv1.Condition)
SetConditions of this PermissionsBoundaryAttachment.
func (*PermissionsBoundaryAttachment) SetDeletionPolicy ¶
func (mg *PermissionsBoundaryAttachment) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this PermissionsBoundaryAttachment.
func (*PermissionsBoundaryAttachment) SetManagementPolicies ¶
func (mg *PermissionsBoundaryAttachment) SetManagementPolicies(r xpv1.ManagementPolicies)
SetManagementPolicies of this PermissionsBoundaryAttachment.
func (*PermissionsBoundaryAttachment) SetObservation ¶
func (tr *PermissionsBoundaryAttachment) SetObservation(obs map[string]any) error
SetObservation for this PermissionsBoundaryAttachment
func (*PermissionsBoundaryAttachment) SetParameters ¶
func (tr *PermissionsBoundaryAttachment) SetParameters(params map[string]any) error
SetParameters for this PermissionsBoundaryAttachment
func (*PermissionsBoundaryAttachment) SetProviderConfigReference ¶
func (mg *PermissionsBoundaryAttachment) SetProviderConfigReference(r *xpv1.Reference)
SetProviderConfigReference of this PermissionsBoundaryAttachment.
func (*PermissionsBoundaryAttachment) SetPublishConnectionDetailsTo ¶
func (mg *PermissionsBoundaryAttachment) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this PermissionsBoundaryAttachment.
func (*PermissionsBoundaryAttachment) SetWriteConnectionSecretToReference ¶
func (mg *PermissionsBoundaryAttachment) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this PermissionsBoundaryAttachment.
type PermissionsBoundaryAttachmentInitParameters ¶
type PermissionsBoundaryAttachmentInitParameters struct {
// The permissions boundary policy. See below.
PermissionsBoundary *PermissionsBoundaryInitParameters `json:"permissionsBoundary,omitempty" tf:"permissions_boundary,omitempty"`
}
func (*PermissionsBoundaryAttachmentInitParameters) DeepCopy ¶
func (in *PermissionsBoundaryAttachmentInitParameters) DeepCopy() *PermissionsBoundaryAttachmentInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PermissionsBoundaryAttachmentInitParameters.
func (*PermissionsBoundaryAttachmentInitParameters) DeepCopyInto ¶
func (in *PermissionsBoundaryAttachmentInitParameters) DeepCopyInto(out *PermissionsBoundaryAttachmentInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PermissionsBoundaryAttachmentList ¶
type PermissionsBoundaryAttachmentList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []PermissionsBoundaryAttachment `json:"items"`
}
PermissionsBoundaryAttachmentList contains a list of PermissionsBoundaryAttachments
func (*PermissionsBoundaryAttachmentList) DeepCopy ¶
func (in *PermissionsBoundaryAttachmentList) DeepCopy() *PermissionsBoundaryAttachmentList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PermissionsBoundaryAttachmentList.
func (*PermissionsBoundaryAttachmentList) DeepCopyInto ¶
func (in *PermissionsBoundaryAttachmentList) DeepCopyInto(out *PermissionsBoundaryAttachmentList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*PermissionsBoundaryAttachmentList) DeepCopyObject ¶
func (in *PermissionsBoundaryAttachmentList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*PermissionsBoundaryAttachmentList) GetItems ¶
func (l *PermissionsBoundaryAttachmentList) GetItems() []resource.Managed
GetItems of this PermissionsBoundaryAttachmentList.
type PermissionsBoundaryAttachmentObservation ¶
type PermissionsBoundaryAttachmentObservation struct {
// Permission Set Amazon Resource Name (ARN) and SSO Instance ARN, separated by a comma (,).
ID *string `json:"id,omitempty" tf:"id,omitempty"`
// The Amazon Resource Name (ARN) of the SSO Instance under which the operation will be executed.
InstanceArn *string `json:"instanceArn,omitempty" tf:"instance_arn,omitempty"`
// The Amazon Resource Name (ARN) of the Permission Set.
PermissionSetArn *string `json:"permissionSetArn,omitempty" tf:"permission_set_arn,omitempty"`
// The permissions boundary policy. See below.
PermissionsBoundary *PermissionsBoundaryObservation `json:"permissionsBoundary,omitempty" tf:"permissions_boundary,omitempty"`
}
func (*PermissionsBoundaryAttachmentObservation) DeepCopy ¶
func (in *PermissionsBoundaryAttachmentObservation) DeepCopy() *PermissionsBoundaryAttachmentObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PermissionsBoundaryAttachmentObservation.
func (*PermissionsBoundaryAttachmentObservation) DeepCopyInto ¶
func (in *PermissionsBoundaryAttachmentObservation) DeepCopyInto(out *PermissionsBoundaryAttachmentObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PermissionsBoundaryAttachmentParameters ¶
type PermissionsBoundaryAttachmentParameters struct {
// The Amazon Resource Name (ARN) of the SSO Instance under which the operation will be executed.
// +kubebuilder:validation:Required
InstanceArn *string `json:"instanceArn" tf:"instance_arn,omitempty"`
// The Amazon Resource Name (ARN) of the Permission Set.
// +crossplane:generate:reference:type=github.com/upbound/provider-aws/apis/ssoadmin/v1beta1.PermissionSet
// +crossplane:generate:reference:extractor=github.com/crossplane/upjet/pkg/resource.ExtractParamPath("arn",true)
// +kubebuilder:validation:Optional
PermissionSetArn *string `json:"permissionSetArn,omitempty" tf:"permission_set_arn,omitempty"`
// Reference to a PermissionSet in ssoadmin to populate permissionSetArn.
// +kubebuilder:validation:Optional
PermissionSetArnRef *v1.Reference `json:"permissionSetArnRef,omitempty" tf:"-"`
// Selector for a PermissionSet in ssoadmin to populate permissionSetArn.
// +kubebuilder:validation:Optional
PermissionSetArnSelector *v1.Selector `json:"permissionSetArnSelector,omitempty" tf:"-"`
// The permissions boundary policy. See below.
// +kubebuilder:validation:Optional
PermissionsBoundary *PermissionsBoundaryParameters `json:"permissionsBoundary,omitempty" tf:"permissions_boundary,omitempty"`
// Region is the region you'd like your resource to be created in.
// +upjet:crd:field:TFTag=-
// +kubebuilder:validation:Required
Region *string `json:"region" tf:"-"`
}
func (*PermissionsBoundaryAttachmentParameters) DeepCopy ¶
func (in *PermissionsBoundaryAttachmentParameters) DeepCopy() *PermissionsBoundaryAttachmentParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PermissionsBoundaryAttachmentParameters.
func (*PermissionsBoundaryAttachmentParameters) DeepCopyInto ¶
func (in *PermissionsBoundaryAttachmentParameters) DeepCopyInto(out *PermissionsBoundaryAttachmentParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PermissionsBoundaryAttachmentSpec ¶
type PermissionsBoundaryAttachmentSpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider PermissionsBoundaryAttachmentParameters `json:"forProvider"`
// THIS IS A BETA FIELD. It will be honored
// unless the Management Policies feature flag is disabled.
// InitProvider holds the same fields as ForProvider, with the exception
// of Identifier and other resource reference fields. The fields that are
// in InitProvider are merged into ForProvider when the resource is created.
// The same fields are also added to the terraform ignore_changes hook, to
// avoid updating them after creation. This is useful for fields that are
// required on creation, but we do not desire to update them after creation,
// for example because of an external controller is managing them, like an
// autoscaler.
InitProvider PermissionsBoundaryAttachmentInitParameters `json:"initProvider,omitempty"`
}
PermissionsBoundaryAttachmentSpec defines the desired state of PermissionsBoundaryAttachment
func (*PermissionsBoundaryAttachmentSpec) DeepCopy ¶
func (in *PermissionsBoundaryAttachmentSpec) DeepCopy() *PermissionsBoundaryAttachmentSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PermissionsBoundaryAttachmentSpec.
func (*PermissionsBoundaryAttachmentSpec) DeepCopyInto ¶
func (in *PermissionsBoundaryAttachmentSpec) DeepCopyInto(out *PermissionsBoundaryAttachmentSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PermissionsBoundaryAttachmentStatus ¶
type PermissionsBoundaryAttachmentStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider PermissionsBoundaryAttachmentObservation `json:"atProvider,omitempty"`
}
PermissionsBoundaryAttachmentStatus defines the observed state of PermissionsBoundaryAttachment.
func (*PermissionsBoundaryAttachmentStatus) DeepCopy ¶
func (in *PermissionsBoundaryAttachmentStatus) DeepCopy() *PermissionsBoundaryAttachmentStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PermissionsBoundaryAttachmentStatus.
func (*PermissionsBoundaryAttachmentStatus) DeepCopyInto ¶
func (in *PermissionsBoundaryAttachmentStatus) DeepCopyInto(out *PermissionsBoundaryAttachmentStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PermissionsBoundaryCustomerManagedPolicyReferenceInitParameters ¶
type PermissionsBoundaryCustomerManagedPolicyReferenceInitParameters struct {
// Name of the customer managed IAM Policy to be attached.
// +crossplane:generate:reference:type=github.com/upbound/provider-aws/apis/iam/v1beta1.Policy
Name *string `json:"name,omitempty" tf:"name,omitempty"`
// Reference to a Policy in iam to populate name.
// +kubebuilder:validation:Optional
NameRef *v1.Reference `json:"nameRef,omitempty" tf:"-"`
// Selector for a Policy in iam to populate name.
// +kubebuilder:validation:Optional
NameSelector *v1.Selector `json:"nameSelector,omitempty" tf:"-"`
// The path to the IAM policy to be attached. The default is /. See IAM Identifiers for more information.
Path *string `json:"path,omitempty" tf:"path,omitempty"`
}
func (*PermissionsBoundaryCustomerManagedPolicyReferenceInitParameters) DeepCopy ¶
func (in *PermissionsBoundaryCustomerManagedPolicyReferenceInitParameters) DeepCopy() *PermissionsBoundaryCustomerManagedPolicyReferenceInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PermissionsBoundaryCustomerManagedPolicyReferenceInitParameters.
func (*PermissionsBoundaryCustomerManagedPolicyReferenceInitParameters) DeepCopyInto ¶
func (in *PermissionsBoundaryCustomerManagedPolicyReferenceInitParameters) DeepCopyInto(out *PermissionsBoundaryCustomerManagedPolicyReferenceInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PermissionsBoundaryCustomerManagedPolicyReferenceObservation ¶
type PermissionsBoundaryCustomerManagedPolicyReferenceObservation struct {
// Name of the customer managed IAM Policy to be attached.
Name *string `json:"name,omitempty" tf:"name,omitempty"`
// The path to the IAM policy to be attached. The default is /. See IAM Identifiers for more information.
Path *string `json:"path,omitempty" tf:"path,omitempty"`
}
func (*PermissionsBoundaryCustomerManagedPolicyReferenceObservation) DeepCopy ¶
func (in *PermissionsBoundaryCustomerManagedPolicyReferenceObservation) DeepCopy() *PermissionsBoundaryCustomerManagedPolicyReferenceObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PermissionsBoundaryCustomerManagedPolicyReferenceObservation.
func (*PermissionsBoundaryCustomerManagedPolicyReferenceObservation) DeepCopyInto ¶
func (in *PermissionsBoundaryCustomerManagedPolicyReferenceObservation) DeepCopyInto(out *PermissionsBoundaryCustomerManagedPolicyReferenceObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PermissionsBoundaryCustomerManagedPolicyReferenceParameters ¶
type PermissionsBoundaryCustomerManagedPolicyReferenceParameters struct {
// Name of the customer managed IAM Policy to be attached.
// +crossplane:generate:reference:type=github.com/upbound/provider-aws/apis/iam/v1beta1.Policy
// +kubebuilder:validation:Optional
Name *string `json:"name,omitempty" tf:"name,omitempty"`
// Reference to a Policy in iam to populate name.
// +kubebuilder:validation:Optional
NameRef *v1.Reference `json:"nameRef,omitempty" tf:"-"`
// Selector for a Policy in iam to populate name.
// +kubebuilder:validation:Optional
NameSelector *v1.Selector `json:"nameSelector,omitempty" tf:"-"`
// The path to the IAM policy to be attached. The default is /. See IAM Identifiers for more information.
// +kubebuilder:validation:Optional
Path *string `json:"path,omitempty" tf:"path,omitempty"`
}
func (*PermissionsBoundaryCustomerManagedPolicyReferenceParameters) DeepCopy ¶
func (in *PermissionsBoundaryCustomerManagedPolicyReferenceParameters) DeepCopy() *PermissionsBoundaryCustomerManagedPolicyReferenceParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PermissionsBoundaryCustomerManagedPolicyReferenceParameters.
func (*PermissionsBoundaryCustomerManagedPolicyReferenceParameters) DeepCopyInto ¶
func (in *PermissionsBoundaryCustomerManagedPolicyReferenceParameters) DeepCopyInto(out *PermissionsBoundaryCustomerManagedPolicyReferenceParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PermissionsBoundaryInitParameters ¶
type PermissionsBoundaryInitParameters struct {
// Specifies the name and path of a customer managed policy. See below.
CustomerManagedPolicyReference *PermissionsBoundaryCustomerManagedPolicyReferenceInitParameters `json:"customerManagedPolicyReference,omitempty" tf:"customer_managed_policy_reference,omitempty"`
// AWS-managed IAM policy ARN to use as the permissions boundary.
ManagedPolicyArn *string `json:"managedPolicyArn,omitempty" tf:"managed_policy_arn,omitempty"`
}
func (*PermissionsBoundaryInitParameters) DeepCopy ¶
func (in *PermissionsBoundaryInitParameters) DeepCopy() *PermissionsBoundaryInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PermissionsBoundaryInitParameters.
func (*PermissionsBoundaryInitParameters) DeepCopyInto ¶
func (in *PermissionsBoundaryInitParameters) DeepCopyInto(out *PermissionsBoundaryInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PermissionsBoundaryObservation ¶
type PermissionsBoundaryObservation struct {
// Specifies the name and path of a customer managed policy. See below.
CustomerManagedPolicyReference *PermissionsBoundaryCustomerManagedPolicyReferenceObservation `json:"customerManagedPolicyReference,omitempty" tf:"customer_managed_policy_reference,omitempty"`
// AWS-managed IAM policy ARN to use as the permissions boundary.
ManagedPolicyArn *string `json:"managedPolicyArn,omitempty" tf:"managed_policy_arn,omitempty"`
}
func (*PermissionsBoundaryObservation) DeepCopy ¶
func (in *PermissionsBoundaryObservation) DeepCopy() *PermissionsBoundaryObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PermissionsBoundaryObservation.
func (*PermissionsBoundaryObservation) DeepCopyInto ¶
func (in *PermissionsBoundaryObservation) DeepCopyInto(out *PermissionsBoundaryObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PermissionsBoundaryParameters ¶
type PermissionsBoundaryParameters struct {
// Specifies the name and path of a customer managed policy. See below.
// +kubebuilder:validation:Optional
CustomerManagedPolicyReference *PermissionsBoundaryCustomerManagedPolicyReferenceParameters `json:"customerManagedPolicyReference,omitempty" tf:"customer_managed_policy_reference,omitempty"`
// AWS-managed IAM policy ARN to use as the permissions boundary.
// +kubebuilder:validation:Optional
ManagedPolicyArn *string `json:"managedPolicyArn,omitempty" tf:"managed_policy_arn,omitempty"`
}
func (*PermissionsBoundaryParameters) DeepCopy ¶
func (in *PermissionsBoundaryParameters) DeepCopy() *PermissionsBoundaryParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PermissionsBoundaryParameters.
func (*PermissionsBoundaryParameters) DeepCopyInto ¶
func (in *PermissionsBoundaryParameters) DeepCopyInto(out *PermissionsBoundaryParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
Source Files
¶
- zz_customermanagedpolicyattachment_terraformed.go
- zz_customermanagedpolicyattachment_types.go
- zz_generated.conversion_hubs.go
- zz_generated.deepcopy.go
- zz_generated.managed.go
- zz_generated.managedlist.go
- zz_generated.resolvers.go
- zz_groupversion_info.go
- zz_permissionsboundaryattachment_terraformed.go
- zz_permissionsboundaryattachment_types.go