Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +groupName=account.aws.upbound.io +versionName=v1beta1
Index ¶
- Constants
- Variables
- type AlternateContact
- func (in *AlternateContact) DeepCopy() *AlternateContact
- func (in *AlternateContact) DeepCopyInto(out *AlternateContact)
- func (in *AlternateContact) DeepCopyObject() runtime.Object
- func (mg *AlternateContact) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *AlternateContact) GetConnectionDetailsMapping() map[string]string
- func (mg *AlternateContact) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *AlternateContact) GetID() string
- func (tr *AlternateContact) GetInitParameters() (map[string]any, error)
- func (mg *AlternateContact) GetManagementPolicies() xpv1.ManagementPolicies
- func (tr *AlternateContact) GetMergedParameters(shouldMergeInitProvider bool) (map[string]any, error)
- func (tr *AlternateContact) GetObservation() (map[string]any, error)
- func (tr *AlternateContact) GetParameters() (map[string]any, error)
- func (mg *AlternateContact) GetProviderConfigReference() *xpv1.Reference
- func (mg *AlternateContact) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *AlternateContact) GetTerraformResourceType() string
- func (tr *AlternateContact) GetTerraformSchemaVersion() int
- func (mg *AlternateContact) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *AlternateContact) Hub()
- func (tr *AlternateContact) LateInitialize(attrs []byte) (bool, error)
- func (mg *AlternateContact) SetConditions(c ...xpv1.Condition)
- func (mg *AlternateContact) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (mg *AlternateContact) SetManagementPolicies(r xpv1.ManagementPolicies)
- func (tr *AlternateContact) SetObservation(obs map[string]any) error
- func (tr *AlternateContact) SetParameters(params map[string]any) error
- func (mg *AlternateContact) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *AlternateContact) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *AlternateContact) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type AlternateContactInitParameters
- type AlternateContactList
- type AlternateContactObservation
- type AlternateContactParameters
- type AlternateContactSpec
- type AlternateContactStatus
- type Region
- func (in *Region) DeepCopy() *Region
- func (in *Region) DeepCopyInto(out *Region)
- func (in *Region) DeepCopyObject() runtime.Object
- func (mg *Region) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *Region) GetConnectionDetailsMapping() map[string]string
- func (mg *Region) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *Region) GetID() string
- func (tr *Region) GetInitParameters() (map[string]any, error)
- func (mg *Region) GetManagementPolicies() xpv1.ManagementPolicies
- func (tr *Region) GetMergedParameters(shouldMergeInitProvider bool) (map[string]any, error)
- func (tr *Region) GetObservation() (map[string]any, error)
- func (tr *Region) GetParameters() (map[string]any, error)
- func (mg *Region) GetProviderConfigReference() *xpv1.Reference
- func (mg *Region) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *Region) GetTerraformResourceType() string
- func (tr *Region) GetTerraformSchemaVersion() int
- func (mg *Region) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *Region) Hub()
- func (tr *Region) LateInitialize(attrs []byte) (bool, error)
- func (mg *Region) SetConditions(c ...xpv1.Condition)
- func (mg *Region) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (mg *Region) SetManagementPolicies(r xpv1.ManagementPolicies)
- func (tr *Region) SetObservation(obs map[string]any) error
- func (tr *Region) SetParameters(params map[string]any) error
- func (mg *Region) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *Region) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *Region) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type RegionInitParameters
- type RegionList
- type RegionObservation
- type RegionParameters
- type RegionSpec
- type RegionStatus
Constants ¶
const ( CRDGroup = "account.aws.upbound.io" CRDVersion = "v1beta1" )
Package type metadata.
Variables ¶
var ( AlternateContact_Kind = "AlternateContact" AlternateContact_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: AlternateContact_Kind}.String() AlternateContact_KindAPIVersion = AlternateContact_Kind + "." + CRDGroupVersion.String() AlternateContact_GroupVersionKind = CRDGroupVersion.WithKind(AlternateContact_Kind) )
Repository type metadata.
var ( // CRDGroupVersion is the API Group Version used to register the objects CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
var ( Region_Kind = "Region" Region_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: Region_Kind}.String() Region_KindAPIVersion = Region_Kind + "." + CRDGroupVersion.String() Region_GroupVersionKind = CRDGroupVersion.WithKind(Region_Kind) )
Repository type metadata.
Functions ¶
This section is empty.
Types ¶
type AlternateContact ¶
type AlternateContact struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.emailAddress) || (has(self.initProvider) && has(self.initProvider.emailAddress))",message="spec.forProvider.emailAddress is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.name) || (has(self.initProvider) && has(self.initProvider.name))",message="spec.forProvider.name is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.phoneNumber) || (has(self.initProvider) && has(self.initProvider.phoneNumber))",message="spec.forProvider.phoneNumber is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.title) || (has(self.initProvider) && has(self.initProvider.title))",message="spec.forProvider.title is a required parameter"
Spec AlternateContactSpec `json:"spec"`
Status AlternateContactStatus `json:"status,omitempty"`
}
AlternateContact is the Schema for the AlternateContacts API. Manages the specified alternate contact attached to an AWS Account. +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,aws}
func (*AlternateContact) DeepCopy ¶
func (in *AlternateContact) DeepCopy() *AlternateContact
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AlternateContact.
func (*AlternateContact) DeepCopyInto ¶
func (in *AlternateContact) DeepCopyInto(out *AlternateContact)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*AlternateContact) DeepCopyObject ¶
func (in *AlternateContact) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*AlternateContact) GetCondition ¶
func (mg *AlternateContact) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this AlternateContact.
func (*AlternateContact) GetConnectionDetailsMapping ¶
func (tr *AlternateContact) GetConnectionDetailsMapping() map[string]string
GetConnectionDetailsMapping for this AlternateContact
func (*AlternateContact) GetDeletionPolicy ¶
func (mg *AlternateContact) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this AlternateContact.
func (*AlternateContact) GetID ¶
func (tr *AlternateContact) GetID() string
GetID returns ID of underlying Terraform resource of this AlternateContact
func (*AlternateContact) GetInitParameters ¶ added in v0.38.0
func (tr *AlternateContact) GetInitParameters() (map[string]any, error)
GetInitParameters of this AlternateContact
func (*AlternateContact) GetManagementPolicies ¶ added in v0.38.0
func (mg *AlternateContact) GetManagementPolicies() xpv1.ManagementPolicies
GetManagementPolicies of this AlternateContact.
func (*AlternateContact) GetMergedParameters ¶ added in v0.44.0
func (tr *AlternateContact) GetMergedParameters(shouldMergeInitProvider bool) (map[string]any, error)
GetInitParameters of this AlternateContact
func (*AlternateContact) GetObservation ¶
func (tr *AlternateContact) GetObservation() (map[string]any, error)
GetObservation of this AlternateContact
func (*AlternateContact) GetParameters ¶
func (tr *AlternateContact) GetParameters() (map[string]any, error)
GetParameters of this AlternateContact
func (*AlternateContact) GetProviderConfigReference ¶
func (mg *AlternateContact) GetProviderConfigReference() *xpv1.Reference
GetProviderConfigReference of this AlternateContact.
func (*AlternateContact) GetPublishConnectionDetailsTo ¶
func (mg *AlternateContact) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this AlternateContact.
func (*AlternateContact) GetTerraformResourceType ¶
func (mg *AlternateContact) GetTerraformResourceType() string
GetTerraformResourceType returns Terraform resource type for this AlternateContact
func (*AlternateContact) GetTerraformSchemaVersion ¶
func (tr *AlternateContact) GetTerraformSchemaVersion() int
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*AlternateContact) GetWriteConnectionSecretToReference ¶
func (mg *AlternateContact) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this AlternateContact.
func (*AlternateContact) Hub ¶ added in v0.47.2
func (tr *AlternateContact) Hub()
Hub marks this type as a conversion hub.
func (*AlternateContact) LateInitialize ¶
func (tr *AlternateContact) LateInitialize(attrs []byte) (bool, error)
LateInitialize this AlternateContact using its observed tfState. returns True if there are any spec changes for the resource.
func (*AlternateContact) SetConditions ¶
func (mg *AlternateContact) SetConditions(c ...xpv1.Condition)
SetConditions of this AlternateContact.
func (*AlternateContact) SetDeletionPolicy ¶
func (mg *AlternateContact) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this AlternateContact.
func (*AlternateContact) SetManagementPolicies ¶ added in v0.38.0
func (mg *AlternateContact) SetManagementPolicies(r xpv1.ManagementPolicies)
SetManagementPolicies of this AlternateContact.
func (*AlternateContact) SetObservation ¶
func (tr *AlternateContact) SetObservation(obs map[string]any) error
SetObservation for this AlternateContact
func (*AlternateContact) SetParameters ¶
func (tr *AlternateContact) SetParameters(params map[string]any) error
SetParameters for this AlternateContact
func (*AlternateContact) SetProviderConfigReference ¶
func (mg *AlternateContact) SetProviderConfigReference(r *xpv1.Reference)
SetProviderConfigReference of this AlternateContact.
func (*AlternateContact) SetPublishConnectionDetailsTo ¶
func (mg *AlternateContact) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this AlternateContact.
func (*AlternateContact) SetWriteConnectionSecretToReference ¶
func (mg *AlternateContact) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this AlternateContact.
type AlternateContactInitParameters ¶ added in v0.38.0
type AlternateContactInitParameters struct {
// ID of the target account when managing member accounts. Will manage current user's account by default if omitted.
AccountID *string `json:"accountId,omitempty" tf:"account_id,omitempty"`
// An email address for the alternate contact.
EmailAddress *string `json:"emailAddress,omitempty" tf:"email_address,omitempty"`
// Name of the alternate contact.
Name *string `json:"name,omitempty" tf:"name,omitempty"`
// Phone number for the alternate contact.
PhoneNumber *string `json:"phoneNumber,omitempty" tf:"phone_number,omitempty"`
// Title for the alternate contact.
Title *string `json:"title,omitempty" tf:"title,omitempty"`
}
func (*AlternateContactInitParameters) DeepCopy ¶ added in v0.38.0
func (in *AlternateContactInitParameters) DeepCopy() *AlternateContactInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AlternateContactInitParameters.
func (*AlternateContactInitParameters) DeepCopyInto ¶ added in v0.38.0
func (in *AlternateContactInitParameters) DeepCopyInto(out *AlternateContactInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type AlternateContactList ¶
type AlternateContactList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []AlternateContact `json:"items"`
}
AlternateContactList contains a list of AlternateContacts
func (*AlternateContactList) DeepCopy ¶
func (in *AlternateContactList) DeepCopy() *AlternateContactList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AlternateContactList.
func (*AlternateContactList) DeepCopyInto ¶
func (in *AlternateContactList) DeepCopyInto(out *AlternateContactList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*AlternateContactList) DeepCopyObject ¶
func (in *AlternateContactList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*AlternateContactList) GetItems ¶
func (l *AlternateContactList) GetItems() []resource.Managed
GetItems of this AlternateContactList.
type AlternateContactObservation ¶
type AlternateContactObservation struct {
// ID of the target account when managing member accounts. Will manage current user's account by default if omitted.
AccountID *string `json:"accountId,omitempty" tf:"account_id,omitempty"`
// Type of the alternate contact. Allowed values are: BILLING, OPERATIONS, SECURITY.
AlternateContactType *string `json:"alternateContactType,omitempty" tf:"alternate_contact_type,omitempty"`
// An email address for the alternate contact.
EmailAddress *string `json:"emailAddress,omitempty" tf:"email_address,omitempty"`
ID *string `json:"id,omitempty" tf:"id,omitempty"`
// Name of the alternate contact.
Name *string `json:"name,omitempty" tf:"name,omitempty"`
// Phone number for the alternate contact.
PhoneNumber *string `json:"phoneNumber,omitempty" tf:"phone_number,omitempty"`
// Title for the alternate contact.
Title *string `json:"title,omitempty" tf:"title,omitempty"`
}
func (*AlternateContactObservation) DeepCopy ¶
func (in *AlternateContactObservation) DeepCopy() *AlternateContactObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AlternateContactObservation.
func (*AlternateContactObservation) DeepCopyInto ¶
func (in *AlternateContactObservation) DeepCopyInto(out *AlternateContactObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type AlternateContactParameters ¶
type AlternateContactParameters struct {
// ID of the target account when managing member accounts. Will manage current user's account by default if omitted.
// +kubebuilder:validation:Optional
AccountID *string `json:"accountId,omitempty" tf:"account_id,omitempty"`
// Type of the alternate contact. Allowed values are: BILLING, OPERATIONS, SECURITY.
// +kubebuilder:validation:Required
AlternateContactType *string `json:"alternateContactType" tf:"alternate_contact_type,omitempty"`
// An email address for the alternate contact.
// +kubebuilder:validation:Optional
EmailAddress *string `json:"emailAddress,omitempty" tf:"email_address,omitempty"`
// Name of the alternate contact.
// +kubebuilder:validation:Optional
Name *string `json:"name,omitempty" tf:"name,omitempty"`
// Phone number for the alternate contact.
// +kubebuilder:validation:Optional
PhoneNumber *string `json:"phoneNumber,omitempty" tf:"phone_number,omitempty"`
// Region is the region you'd like your resource to be created in.
// +upjet:crd:field:TFTag=-
// +kubebuilder:validation:Required
Region *string `json:"region" tf:"-"`
// Title for the alternate contact.
// +kubebuilder:validation:Optional
Title *string `json:"title,omitempty" tf:"title,omitempty"`
}
func (*AlternateContactParameters) DeepCopy ¶
func (in *AlternateContactParameters) DeepCopy() *AlternateContactParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AlternateContactParameters.
func (*AlternateContactParameters) DeepCopyInto ¶
func (in *AlternateContactParameters) DeepCopyInto(out *AlternateContactParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type AlternateContactSpec ¶
type AlternateContactSpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider AlternateContactParameters `json:"forProvider"`
// THIS IS A BETA FIELD. It will be honored
// unless the Management Policies feature flag is disabled.
// InitProvider holds the same fields as ForProvider, with the exception
// of Identifier and other resource reference fields. The fields that are
// in InitProvider are merged into ForProvider when the resource is created.
// The same fields are also added to the terraform ignore_changes hook, to
// avoid updating them after creation. This is useful for fields that are
// required on creation, but we do not desire to update them after creation,
// for example because of an external controller is managing them, like an
// autoscaler.
InitProvider AlternateContactInitParameters `json:"initProvider,omitempty"`
}
AlternateContactSpec defines the desired state of AlternateContact
func (*AlternateContactSpec) DeepCopy ¶
func (in *AlternateContactSpec) DeepCopy() *AlternateContactSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AlternateContactSpec.
func (*AlternateContactSpec) DeepCopyInto ¶
func (in *AlternateContactSpec) DeepCopyInto(out *AlternateContactSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type AlternateContactStatus ¶
type AlternateContactStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider AlternateContactObservation `json:"atProvider,omitempty"`
}
AlternateContactStatus defines the observed state of AlternateContact.
func (*AlternateContactStatus) DeepCopy ¶
func (in *AlternateContactStatus) DeepCopy() *AlternateContactStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AlternateContactStatus.
func (*AlternateContactStatus) DeepCopyInto ¶
func (in *AlternateContactStatus) DeepCopyInto(out *AlternateContactStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Region ¶ added in v1.14.0
type Region struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.enabled) || (has(self.initProvider) && has(self.initProvider.enabled))",message="spec.forProvider.enabled is a required parameter"
Spec RegionSpec `json:"spec"`
Status RegionStatus `json:"status,omitempty"`
}
Region is the Schema for the Regions API. Enable (Opt-In) or Disable (Opt-Out) a particular Region for an AWS account +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,aws}
func (*Region) DeepCopy ¶ added in v1.14.0
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Region.
func (*Region) DeepCopyInto ¶ added in v1.14.0
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Region) DeepCopyObject ¶ added in v1.14.0
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*Region) GetCondition ¶ added in v1.14.0
func (mg *Region) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this Region.
func (*Region) GetConnectionDetailsMapping ¶ added in v1.14.0
GetConnectionDetailsMapping for this Region
func (*Region) GetDeletionPolicy ¶ added in v1.14.0
func (mg *Region) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this Region.
func (*Region) GetID ¶ added in v1.14.0
GetID returns ID of underlying Terraform resource of this Region
func (*Region) GetInitParameters ¶ added in v1.14.0
GetInitParameters of this Region
func (*Region) GetManagementPolicies ¶ added in v1.14.0
func (mg *Region) GetManagementPolicies() xpv1.ManagementPolicies
GetManagementPolicies of this Region.
func (*Region) GetMergedParameters ¶ added in v1.14.0
GetInitParameters of this Region
func (*Region) GetObservation ¶ added in v1.14.0
GetObservation of this Region
func (*Region) GetParameters ¶ added in v1.14.0
GetParameters of this Region
func (*Region) GetProviderConfigReference ¶ added in v1.14.0
GetProviderConfigReference of this Region.
func (*Region) GetPublishConnectionDetailsTo ¶ added in v1.14.0
func (mg *Region) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this Region.
func (*Region) GetTerraformResourceType ¶ added in v1.14.0
GetTerraformResourceType returns Terraform resource type for this Region
func (*Region) GetTerraformSchemaVersion ¶ added in v1.14.0
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*Region) GetWriteConnectionSecretToReference ¶ added in v1.14.0
func (mg *Region) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this Region.
func (*Region) Hub ¶ added in v1.14.0
func (tr *Region) Hub()
Hub marks this type as a conversion hub.
func (*Region) LateInitialize ¶ added in v1.14.0
LateInitialize this Region using its observed tfState. returns True if there are any spec changes for the resource.
func (*Region) SetConditions ¶ added in v1.14.0
SetConditions of this Region.
func (*Region) SetDeletionPolicy ¶ added in v1.14.0
func (mg *Region) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this Region.
func (*Region) SetManagementPolicies ¶ added in v1.14.0
func (mg *Region) SetManagementPolicies(r xpv1.ManagementPolicies)
SetManagementPolicies of this Region.
func (*Region) SetObservation ¶ added in v1.14.0
SetObservation for this Region
func (*Region) SetParameters ¶ added in v1.14.0
SetParameters for this Region
func (*Region) SetProviderConfigReference ¶ added in v1.14.0
SetProviderConfigReference of this Region.
func (*Region) SetPublishConnectionDetailsTo ¶ added in v1.14.0
func (mg *Region) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this Region.
func (*Region) SetWriteConnectionSecretToReference ¶ added in v1.14.0
func (mg *Region) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this Region.
type RegionInitParameters ¶ added in v1.14.0
type RegionInitParameters struct {
// The ID of the target account when managing member accounts. Will manage current user's account by default if omitted. To use this parameter, the caller must be an identity in the organization's management account or a delegated administrator account. The specified account ID must also be a member account in the same organization. The organization must have all features enabled, and the organization must have trusted access enabled for the Account Management service, and optionally a delegated admin account assigned.
AccountID *string `json:"accountId,omitempty" tf:"account_id,omitempty"`
// Whether the region is enabled.
Enabled *bool `json:"enabled,omitempty" tf:"enabled,omitempty"`
}
func (*RegionInitParameters) DeepCopy ¶ added in v1.14.0
func (in *RegionInitParameters) DeepCopy() *RegionInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RegionInitParameters.
func (*RegionInitParameters) DeepCopyInto ¶ added in v1.14.0
func (in *RegionInitParameters) DeepCopyInto(out *RegionInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RegionList ¶ added in v1.14.0
type RegionList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Region `json:"items"`
}
RegionList contains a list of Regions
func (*RegionList) DeepCopy ¶ added in v1.14.0
func (in *RegionList) DeepCopy() *RegionList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RegionList.
func (*RegionList) DeepCopyInto ¶ added in v1.14.0
func (in *RegionList) DeepCopyInto(out *RegionList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*RegionList) DeepCopyObject ¶ added in v1.14.0
func (in *RegionList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*RegionList) GetItems ¶ added in v1.14.0
func (l *RegionList) GetItems() []resource.Managed
GetItems of this RegionList.
type RegionObservation ¶ added in v1.14.0
type RegionObservation struct {
// The ID of the target account when managing member accounts. Will manage current user's account by default if omitted. To use this parameter, the caller must be an identity in the organization's management account or a delegated administrator account. The specified account ID must also be a member account in the same organization. The organization must have all features enabled, and the organization must have trusted access enabled for the Account Management service, and optionally a delegated admin account assigned.
AccountID *string `json:"accountId,omitempty" tf:"account_id,omitempty"`
// Whether the region is enabled.
Enabled *bool `json:"enabled,omitempty" tf:"enabled,omitempty"`
ID *string `json:"id,omitempty" tf:"id,omitempty"`
// The region opt status.
OptStatus *string `json:"optStatus,omitempty" tf:"opt_status,omitempty"`
// The region name to manage.
RegionName *string `json:"regionName,omitempty" tf:"region_name,omitempty"`
}
func (*RegionObservation) DeepCopy ¶ added in v1.14.0
func (in *RegionObservation) DeepCopy() *RegionObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RegionObservation.
func (*RegionObservation) DeepCopyInto ¶ added in v1.14.0
func (in *RegionObservation) DeepCopyInto(out *RegionObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RegionParameters ¶ added in v1.14.0
type RegionParameters struct {
// The ID of the target account when managing member accounts. Will manage current user's account by default if omitted. To use this parameter, the caller must be an identity in the organization's management account or a delegated administrator account. The specified account ID must also be a member account in the same organization. The organization must have all features enabled, and the organization must have trusted access enabled for the Account Management service, and optionally a delegated admin account assigned.
// +kubebuilder:validation:Optional
AccountID *string `json:"accountId,omitempty" tf:"account_id,omitempty"`
// Whether the region is enabled.
// +kubebuilder:validation:Optional
Enabled *bool `json:"enabled,omitempty" tf:"enabled,omitempty"`
// Region is the region you'd like your resource to be created in.
// +upjet:crd:field:TFTag=-
// +kubebuilder:validation:Required
Region *string `json:"region" tf:"-"`
// The region name to manage.
// +kubebuilder:validation:Required
RegionName *string `json:"regionName" tf:"region_name,omitempty"`
}
func (*RegionParameters) DeepCopy ¶ added in v1.14.0
func (in *RegionParameters) DeepCopy() *RegionParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RegionParameters.
func (*RegionParameters) DeepCopyInto ¶ added in v1.14.0
func (in *RegionParameters) DeepCopyInto(out *RegionParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RegionSpec ¶ added in v1.14.0
type RegionSpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider RegionParameters `json:"forProvider"`
// THIS IS A BETA FIELD. It will be honored
// unless the Management Policies feature flag is disabled.
// InitProvider holds the same fields as ForProvider, with the exception
// of Identifier and other resource reference fields. The fields that are
// in InitProvider are merged into ForProvider when the resource is created.
// The same fields are also added to the terraform ignore_changes hook, to
// avoid updating them after creation. This is useful for fields that are
// required on creation, but we do not desire to update them after creation,
// for example because of an external controller is managing them, like an
// autoscaler.
InitProvider RegionInitParameters `json:"initProvider,omitempty"`
}
RegionSpec defines the desired state of Region
func (*RegionSpec) DeepCopy ¶ added in v1.14.0
func (in *RegionSpec) DeepCopy() *RegionSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RegionSpec.
func (*RegionSpec) DeepCopyInto ¶ added in v1.14.0
func (in *RegionSpec) DeepCopyInto(out *RegionSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RegionStatus ¶ added in v1.14.0
type RegionStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider RegionObservation `json:"atProvider,omitempty"`
}
RegionStatus defines the observed state of Region.
func (*RegionStatus) DeepCopy ¶ added in v1.14.0
func (in *RegionStatus) DeepCopy() *RegionStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RegionStatus.
func (*RegionStatus) DeepCopyInto ¶ added in v1.14.0
func (in *RegionStatus) DeepCopyInto(out *RegionStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.